@@ -30,7 +30,6 @@
 
 from PAMI.correlatedPattern.basic import abstract as _ab
 
-#frequentPatterns = {}
 class _Node:
     """
     A class used to represent the node of frequentPatternTree
@@ -213,8 +212,12 @@ class _Tree:
 class CPGrowth(_ab._correlatedPatterns):
     """
         CPGrowth is one of the fundamental algorithm to discover correlated frequent patterns in a transactional database.
-        it is based on traditional Fpgrowth Algorithm,This algorithm uses breadth-first search technique to find the 
+        it is based on traditional FPGrowth Algorithm,This algorithm uses breadth-first search technique to find the
         correlated Frequent patterns in transactional database.
+
+    Reference :
+    ----------
+        Lee, Y.K., Kim, W.Y., Cao, D., Han, J. (2003). CoMine: efficient mining of correlated patterns. In ICDM (pp. 581–584).
     
     Attributes :
     ----------
@@ -257,7 +260,7 @@ class CPGrowth(_ab._correlatedPatterns):
             Mining process will start from here
         getPatterns()
             Complete set of patterns will be retrieved with this function
-        savePatterns(oFile)
+        save(oFile)
             Complete set of frequent patterns will be loaded in to a output file
         getPatternsAsDataFrame()
             Complete set of frequent patterns will be loaded in to a dataframe
@@ -279,21 +282,25 @@ class CPGrowth(_ab._correlatedPatterns):
         saveItemSet(prefix, prefixLength, support)
             To save the frequent patterns mined form frequentPatternTree
 
-    Executing the code on terminal
+    Executing the code on terminal :
     ------------------------------
-        Format: python3 CPGrowth.py <inputFile> <outputFile> <minSup> <minAllConf> <sep>
-        Examples: python3 CPGrowth.py inp.txt output.txt 4.0 0.3   (minSup will be considered in percentage of database transactions)
-                  python3 CPGrowth.py  patterns.txt 4  0.3   (minSup will be considered in support count or frequency)
+        Format:
+                python3 CPGrowth.py <inputFile> <outputFile> <minSup> <minAllConf> <sep>
+        Examples:
+                python3 CPGrowth.py inp.txt output.txt 4.0 0.3   (minSup will be considered in percentage of database transactions)
+
+                python3 CPGrowth.py  patterns.txt 4  0.3   (minSup will be considered in support count or frequency)
                                                                 (it will consider '\t' as separator)
-                  python3 CPGrowth.py sampleDB.txt patterns.txt 0.23 0.2  , 
+
+                python3 CPGrowth.py sampleDB.txt patterns.txt 0.23 0.2  ,
                                                                 (it will consider ',' as separator)
 
-    Sample run of the importing code:
+    Sample run of the importing code :
     ---------------------------------
 
         from PAMI.correlatedPattern.basic import CPGrowth as alg
 
-        obj = alg.CPGrowth(iFile, minSup,minAllConf)
+        obj = alg.CPGrowth(iFile, minSup, minAllConf)
 
         obj.startMine()
 
@@ -301,7 +308,7 @@ class CPGrowth(_ab._correlatedPatterns):
 
         print("Total number of correlated frequent Patterns:", len(correlatedPatterns))
 
-        obj.savePatterns(oFile)
+        obj.save(oFile)
 
         Df = obj.getPatternInDf()
 
@@ -335,7 +342,7 @@ class CPGrowth(_ab._correlatedPatterns):
     _Database = []
     _mapSupport = {}
     _lno = 0
-    _tree = _Tree()
+    _tree = str()
     _itemSetBuffer = None
     _fpNodeTempBuffer = []
     _itemSetCount = 0
@@ -373,7 +380,6 @@ class CPGrowth(_ab._correlatedPatterns):
                             line.strip()
                             temp = [i.rstrip() for i in line.split(self._sep)]
                             temp = [x for x in temp if x]
-                            print(temp)
                             self._Database.append(temp)
                 except IOError:
                     print("File Not Found")
@@ -428,7 +434,7 @@ class CPGrowth(_ab._correlatedPatterns):
         for i in range(prefixLength):
             l.append(prefix[i])
         self._itemSetCount += 1
-        self._finalPatterns[tuple(l)] = str(support)+" : "+str(allconf)
+        self._finalPatterns[tuple(l)] = [support, allconf]
     
     def _convert(self, value):
         """
@@ -542,7 +548,7 @@ class CPGrowth(_ab._correlatedPatterns):
     
     def startMine(self):
         """
-        main program to start the operation
+        main method to start
 
         """
         self._startTime = _ab._time.time()
@@ -550,6 +556,7 @@ class CPGrowth(_ab._correlatedPatterns):
             raise Exception("Please enter the file path or file name:")
         self._creatingItemSets()
         self._minSup = self._convert(self._minSup)
+        self._tree = _Tree()
         self._finalPatterns = {}
         self._frequentOneItem()
         self._mapSupport = {k: v for k, v in self._mapSupport.items() if v >= self._minSup}
@@ -616,11 +623,14 @@ class CPGrowth(_ab._correlatedPatterns):
         dataframe = {}
         data = []
         for a, b in self._finalPatterns.items():
-            data.append([a, b])
-            dataframe = _ab._pd.DataFrame(data, columns=['Patterns', 'Support'])
+            pat = " "
+            for i in a:
+                pat += str(i) + " "
+            data.append([pat, b[0], b[1]])
+            dataframe = _ab._pd.DataFrame(data, columns=['Patterns', 'Support', 'Confidence'])
         return dataframe
 
-    def savePatterns(self, outFile):
+    def save(self, outFile):
         """
         Complete set of frequent patterns will be loaded in to a output file
 
@@ -632,8 +642,8 @@ class CPGrowth(_ab._correlatedPatterns):
         for x, y in self._finalPatterns.items():
             pat = ""
             for i in x:
-                pat += str(i) + " "
-            patternsAndSupport = pat + ": " + str(y)
+                pat += str(i) + "\t"
+            patternsAndSupport = pat.strip() + ":" + str(y[0]) + ":" + str(y[1])
             writer.write("%s \n" % patternsAndSupport)
 
     def getPatterns(self):
@@ -645,6 +655,11 @@ class CPGrowth(_ab._correlatedPatterns):
         """
         return self._finalPatterns
 
+    def printResults(self):
+        print("Total number of Correlated Patterns:", len(self.getPatterns()))
+        print("Total Memory in USS:", self.getMemoryUSS())
+        print("Total Memory in RSS", self.getMemoryRSS())
+        print("Total ExecutionTime in ms:",  self.getRuntime())
 
 if __name__ == "__main__":
     _ap = str()
@@ -654,29 +669,10 @@ if __name__ == "__main__":
         if len(_ab._sys.argv) == 5:
             _ap = CPGrowth(_ab._sys.argv[1], _ab._sys.argv[3], float(_ab._sys.argv[4]))
         _ap.startMine()
-        _correlatedPatterns = _ap.getPatterns()
-        print("Total number of correlated-Frequent Patterns:", len(_correlatedPatterns))
-        _ap.savePatterns(_ab._sys.argv[2])
-        _memUSS = _ap.getMemoryUSS()
-        print("Total Memory in USS:", _memUSS)
-        _memRSS = _ap.getMemoryRSS()
-        print("Total Memory in RSS", _memRSS)
-        _run = _ap.getRuntime()
-        print("Total ExecutionTime in seconds:", _run)
+        print("Total number of Correlated-Frequent Patterns:", len(_ap.getPatterns()))
+        _ap.save(_ab._sys.argv[2])
+        print("Total Memory in USS:", _ap.getMemoryUSS())
+        print("Total Memory in RSS", _ap.getMemoryRSS())
+        print("Total ExecutionTime in seconds:", _ap.getRuntime())
     else:
-        l = [0.0007, 0.0009, 0.001, 0.002, 0.003, 0.01]
-        for i in l:
-            ap = CPGrowth('https://www.u-aizu.ac.jp/~udayrage/datasets/transactionalDatabases/transactional_retail.csv',
-                          i, 0.7)
-            ap.startMine()
-            print(ap._minSup, ap._minAllConf, len(ap._Database))
-            correlatedPatterns = ap.getPatterns()
-            print("Total number of correlated-Frequent Patterns:", len(correlatedPatterns))
-            ap.savePatterns('/Users/Likhitha/Downloads/output')
-            memUSS = ap.getMemoryUSS()
-            print("Total Memory in USS:", memUSS)
-            memRSS = ap.getMemoryRSS()
-            print("Total Memory in RSS", memRSS)
-            run = ap.getRuntime()
-            print("Total ExecutionTime in seconds:", run)
         print("Error! The number of input parameters do not match the total number of parameters provided")
