@@ -227,9 +227,9 @@ class _Tree:
 
 class CPGrowthPlus(_ab._correlatedPatterns):
     """ 
-         cpgrowth is one of the fundamental algorithm to discover Correlated frequent patterns in a transactional database.
-        it is based on traditional Fpgrowth Algorithm,This algorithm uses breadth-first search technique to find the 
-        correlated Frequent patterns in transactional database.
+         CPGrowthPlus is one of the efficient algorithm to discover Correlated frequent patterns in a transactional database.
+         Using Item Support Intervals technique which is generating correlated patterns of higher order by combining only with items that
+         have support within specified interval.
 
     Reference :
     ---------
@@ -279,7 +279,7 @@ class CPGrowthPlus(_ab._correlatedPatterns):
             Mining process will start from here
         getPatterns()
             Complete set of patterns will be retrieved with this function
-        savePatterns(oFile)
+        save(oFile)
             Complete set of frequent patterns will be loaded in to a output file
         getPatternsAsDataFrame()
             Complete set of frequent patterns will be loaded in to a dataframe
@@ -331,7 +331,7 @@ class CPGrowthPlus(_ab._correlatedPatterns):
 
         print("Total number of correlated frequent Patterns:", len(correlatedPatterns))
 
-        obj.savePatterns(oFile)
+        obj.save(oFile)
 
         Df = obj.getPatternInDf()
 
@@ -365,7 +365,7 @@ class CPGrowthPlus(_ab._correlatedPatterns):
     _Database = []
     _mapSupport = {}
     _lno = 0
-    _tree = _Tree()
+    _tree = str()
     _itemSetBuffer = None
     _fpNodeTempBuffer = []
     _itemSetCount = 0
@@ -438,7 +438,7 @@ class CPGrowthPlus(_ab._correlatedPatterns):
         for i in range(prefixLength):
             sample.append(prefix[i])
         self._itemSetCount += 1
-        self._finalPatterns[tuple(sample)] = str(support)+" : "+str(ratio)
+        self._finalPatterns[tuple(sample)] = [support, ratio]
 
     def _saveAllCombinations(self, tempBuffer, s, position, prefix, prefixLength):
         """
@@ -573,10 +573,10 @@ class CPGrowthPlus(_ab._correlatedPatterns):
             raise Exception("Please enter the Minimum Support")
         self._creatingItemSets()
         self._finalPatterns = {}
+        self._tree = _Tree()
         self._minSup = self._convert(self._minSup)
         self._frequentOneItem()
         self._mapSupport = {k: v for k, v in self._mapSupport.items() if v >= self._minSup}
-        #print(len(self.mapSupport))
         _itemSetBuffer = [k for k, v in sorted(self._mapSupport.items(), key=lambda x: x[1], reverse=True)]
         for i in self._Database:
             _transaction = []
@@ -646,11 +646,14 @@ class CPGrowthPlus(_ab._correlatedPatterns):
         dataframe = {}
         data = []
         for a, b in self._finalPatterns.items():
-            data.append([a, b])
-            dataframe = _ab._pd.DataFrame(data, columns=['Patterns', 'Support'])
+            pat = " "
+            for i in a:
+                pat += str(i) + " "
+            data.append([pat, b[0], b[1]])
+            dataframe = _ab._pd.DataFrame(data, columns=['Patterns', 'Support', 'Confidence'])
         return dataframe
 
-    def savePatterns(self, outFile):
+    def save(self, outFile):
         """
         Complete set of frequent patterns will be loaded in to a output file
 
@@ -662,8 +665,8 @@ class CPGrowthPlus(_ab._correlatedPatterns):
         for x, y in self._finalPatterns.items():
             pattern = str()
             for i in x:
-                pattern = pattern + i + " "
-            s1 = str(pattern) + ": " + str(y)
+                pattern = pattern + i + "\t"
+            s1 = str(pattern.strip()) + ":" + str(y[0]) + ":" + str(y[1])
             writer.write("%s \n" % s1)
 
     def getPatterns(self):
@@ -675,6 +678,12 @@ class CPGrowthPlus(_ab._correlatedPatterns):
         """
         return self._finalPatterns
 
+    def printResults(self):
+        print("Total number of Correlated Patterns:", len(self.getPatterns()))
+        print("Total Memory in USS:", self.getMemoryUSS())
+        print("Total Memory in RSS", self.getMemoryRSS())
+        print("Total ExecutionTime in ms:",  self.getRuntime())
+
 
 if __name__ == "__main__":
     _ap = str()
@@ -685,28 +694,10 @@ if __name__ == "__main__":
             _ap = CPGrowthPlus(_ab._sys.argv[1], _ab._sys.argv[3], float(_ab._sys.argv[4]))
         _ap.startMine()
         _correlatedPatterns = _ap.getPatterns()
-        print("Total number of Correlated-Frequent Patterns:", len(_correlatedPatterns))
-        _ap.savePatterns(_ab._sys.argv[2])
-        _memUSS = _ap.getMemoryUSS()
-        print("Total Memory in USS:", _memUSS)
-        _memRSS = _ap.getMemoryRSS()
-        print("Total Memory in RSS", _memRSS)
-        _run = _ap.getRuntime()
-        print("Total ExecutionTime in seconds:", _run)
+        print("Total number of Correlated-Frequent Patterns:", len(_ap.getPatterns()))
+        _ap.save(_ab._sys.argv[2])
+        print("Total Memory in USS:", _ap.getMemoryUSS())
+        print("Total Memory in RSS", _ap.getMemoryRSS())
+        print("Total ExecutionTime in seconds:", _ap.getRuntime())
     else:
-        '''l = [0.0007, 0.0009, 0.001, 0.002, 0.003, 0.01]
-        for i in l:
-            ap = CPGrowthPlus('https://www.u-aizu.ac.jp/~udayrage/datasets/transactionalDatabases/transactional_retail.csv',
-                          i, 0.7)
-            ap.startMine()
-            print(ap._minSup, ap._minAllConf, len(ap._Database))
-            correlatedPatterns = ap.getPatterns()
-            print("Total number of correlated-Frequent Patterns:", len(correlatedPatterns))
-            ap.savePatterns('/Users/Likhitha/Downloads/output')
-            memUSS = ap.getMemoryUSS()
-            print("Total Memory in USS:", memUSS)
-            memRSS = ap.getMemoryRSS()
-            print("Total Memory in RSS", memRSS)
-            run = ap.getRuntime()
-            print("Total ExecutionTime in seconds:", run)'''
         print("Error! The number of input parameters do not match the total number of parameters provided")
