@@ -18,6 +18,7 @@ from PAMI.frequentPattern.maximal import abstract as _ab
 
 
 _minSup = str()
+global maximalTree
 
 
 class _Node(object):
@@ -104,7 +105,7 @@ class _Tree(object):
         self.root = _Node(None, {})
         self.summaries = {}
         self.info = {}
-        self.maximalTree = _MPTree()
+        #self.maximalTree = _MPTree()
 
     def addTransaction(self, transaction):
         """
@@ -229,6 +230,7 @@ class _Tree(object):
 
         :return: the maximal frequent patterns
         """
+        global maximalTree
         for i in sorted(self.summaries, key=lambda x: (self.info.get(x), -x)):
             pattern = prefix[:]
             pattern.append(i)
@@ -240,13 +242,13 @@ class _Tree(object):
             for la in info:
                 tail.append(la)
             sub = head + tail
-            if self.maximalTree.checkerSub(sub) == 1:
+            if maximalTree.checkerSub(sub) == 1:
                 for pat in range(len(condPatterns)):
                     conditional_tree.addConditionalTransaction(condPatterns[pat], tids[pat])
                 if len(condPatterns) >= 1:
                     conditional_tree.generatePatterns(pattern, patterns)
                 else:
-                    self.maximalTree.addTransaction(pattern)
+                    maximalTree.addTransaction(pattern)
                     patterns[tuple(pattern)] = self.info[i]
             self.removeNode(i)
 
@@ -360,7 +362,7 @@ class _MPTree(object):
 
 
 # Initialising the  variable for maximal tree
-#maximalTree = MPTree()
+maximalTree = _MPTree()
 
 
 class MaxFPGrowth(_ab._frequentPatterns):
@@ -411,7 +413,7 @@ class MaxFPGrowth(_ab._frequentPatterns):
             Mining process will start from here
         getPatterns()
             Complete set of patterns will be retrieved with this function
-        savePatterns(oFile)
+        save(oFile)
             Complete set of frequent patterns will be loaded in to a output file
         getPatternsAsDataFrame()
             Complete set of frequent patterns will be loaded in to a dataframe
@@ -456,7 +458,7 @@ class MaxFPGrowth(_ab._frequentPatterns):
 
         print("Total number of Frequent Patterns:", len(frequentPatterns))
 
-        obj.savePatterns("patterns")
+        obj.save("patterns")
 
         Df = obj.getPatternsAsDataFrame()
 
@@ -641,7 +643,7 @@ class MaxFPGrowth(_ab._frequentPatterns):
             pattern = str()
             x = self._convertItems(x)
             for i in x:
-                pattern = pattern + i + " "
+                pattern = pattern + i + "\t"
             self._finalPatterns[pattern] = y
         self._endTime = _ab._time.time()
         process = _ab._psutil.Process(_ab._os.getpid())
@@ -692,11 +694,11 @@ class MaxFPGrowth(_ab._frequentPatterns):
         dataFrame = {}
         data = []
         for a, b in self._finalPatterns.items():
-            data.append([a, b])
+            data.append([a.replace('\t', ' '), b])
             dataFrame = _ab._pd.DataFrame(data, columns=['Patterns', 'Support'])
         return dataFrame
 
-    def savePatterns(self, outFile):
+    def save(self, outFile):
         """Complete set of frequent patterns will be loaded in to a output file
 
         :param outFile: name of the output file
@@ -706,7 +708,7 @@ class MaxFPGrowth(_ab._frequentPatterns):
         self._oFile = outFile
         writer = open(self._oFile, 'w+')
         for x, y in self._finalPatterns.items():
-            s1 = x + ":" + str(y)
+            s1 = x.strip() + ":" + str(y)
             writer.write("%s \n" % s1)
 
     def getPatterns(self):
@@ -717,38 +719,26 @@ class MaxFPGrowth(_ab._frequentPatterns):
         :rtype: dict
         """
         return self._finalPatterns
+    
+    def printResults(self):
+        print('Total number of Maximal Frequent Patterns: ' + str(self.getPatterns()))
+        print('Runtime: ' + str(self.getRuntime()))
+        print('Memory (RSS): ' + str(self.getMemoryRSS()))
+        print('Memory (USS): ' + str(self.getMemoryUSS()))
 
 
 if __name__ == "__main__":
-    ap = str()
+    _ap = str()
     if len(_ab._sys.argv) == 4 or len(_ab._sys.argv) == 5:
         if len(_ab._sys.argv) == 5:
-            ap = MaxFPGrowth(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4])
+            _ap = MaxFPGrowth(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4])
         if len(_ab._sys.argv) == 4:
-            ap = MaxFPGrowth(_ab._sys.argv[1], _ab._sys.argv[3])
-        ap.startMine()
-        Patterns = ap.getPatterns()
-        print("Total number of Maximal Frequent Patterns:", len(Patterns))
-        ap.savePatterns(_ab._sys.argv[2])
-        memUSS = ap.getMemoryUSS()
-        print("Total Memory in USS:", memUSS)
-        memRSS = ap.getMemoryRSS()
-        print("Total Memory in RSS", memRSS)
-        run = ap.getRuntime()
-        print("Total ExecutionTime in ms:", run)
+            _ap = MaxFPGrowth(_ab._sys.argv[1], _ab._sys.argv[3])
+        _ap.startMine()
+        _ap.save(_ab._sys.argv[2])
+        print("Total number of Maximal Frequent Patterns:", len(_ap.getPatterns()))
+        print("Total Memory in USS:",  _ap.getMemoryUSS())
+        print("Total Memory in RSS", _ap.getMemoryRSS())
+        print("Total ExecutionTime in ms:", _ap.getRuntime())
     else:
-        '''l = [0.001, 0.002, 0.003, 0.004, 0.005]
-        for i in l:
-            ap = MaxFPGrowth('https://www.u-aizu.ac.jp/~udayrage/datasets/temporalDatabases/temporal_T10I4D100K.csv',
-                       i)
-            ap.startMine()
-            Patterns = ap.getPatterns()
-            print("Total number of Closed Frequent Patterns:", len(Patterns))
-            ap.savePatterns('/Users/Likhitha/Downloads/output')
-            memUSS = ap.getMemoryUSS()
-            print("Total Memory in USS:", memUSS)
-            memRSS = ap.getMemoryRSS()
-            print("Total Memory in RSS", memRSS)
-            run = ap.getRuntime()
-            print("Total ExecutionTime in ms:", run)'''
         print("Error! The number of input parameters do not match the total number of parameters provided")
