@@ -1,12 +1,9 @@
-
 from PAMI.frequentSpatialPattern.basic import abstract as _ab
 
 
-
 class _Node:
     """
     A class used to represent the node of frequentPatternTree
-
     Attributes
     ----------
         item : int
@@ -17,7 +14,6 @@ class _Node:
             To maintain the children of node
         prefix : list
             To maintain the prefix of node
-
     """
 
     def __init__(self, item, count, children):
@@ -30,14 +26,12 @@ class _Node:
 class _Tree:
     """
     A class used to represent the frequentPatternGrowth tree structure
-
     Attributes
     ----------
         root : Node
             The first node of the tree set to Null.
         nodeLink : dict
             Stores the nodes which shares same item
-
     Methods
     -------
         createTree(transaction,count)
@@ -63,7 +57,6 @@ class _Tree:
     def createTree(self, transaction, count):
         """
         Create tree or add transaction into yourself.
-
         :param transaction: list
         :param count: int
         :return: Tree
@@ -101,7 +94,8 @@ class _Tree:
         pTree = _Tree()
         for node in self.nodeLink[item]:
             # print(node.item, neighbour[node.item])
-            node.prefix = [item for item in node.prefix if item in neighbour.get(node.item)]
+            if node.item in neighbour:
+                node.prefix = [item for item in node.prefix if item in neighbour.get(node.item)]
             pTree.createTree(node.prefix, node.count)
         return pTree
 
@@ -197,14 +191,13 @@ class FSPGrowth(_ab._spatialFrequentPatterns):
             To store the total amount of USS memory consumed by the program
         memoryRSS : float
             To store the total amount of RSS memory consumed by the program
-
     Methods
     -------
         startMine()
             This function starts pattern mining.
         getPatterns()
             Complete set of patterns will be retrieved with this function
-        savePatterns(oFile)
+        save(oFile)
             Complete set of frequent patterns will be loaded in to a output file
         getPatternsInDataFrame()
             Complete set of frequent patterns will be loaded in to a dataframe
@@ -234,43 +227,25 @@ class FSPGrowth(_ab._spatialFrequentPatterns):
     ------------------------------
         Format:
             python3 FSPGrowth.py <inputFile> <outputFile> <neighbourFile> <minSup>
-
         Examples:
             python3 FSPGrowth.py sampleTDB.txt output.txt sampleN.txt 0.5 (minSup will be considered in percentage of database transactions)
-
             python3 FSPGrowth.py sampleTDB.txt output.txt sampleN.txt 3 (minSup will be considered in support count or frequency)
                                                                 (it considers "\t" as separator)
-
             python3 FSPGrowth.py sampleTDB.txt output.txt sampleN.txt 3 ','  (it will consider "," as a separator)
-
     Sample run of importing the code :
     -------------------------------
-
         from PAMI.frequentSpatialPattern.basic import FSPGrowth as alg
-
         obj = alg.FSPGrowth("sampleTDB.txt", "sampleN.txt", 5)
-
         obj.startMine()
-
         spatialFrequentPatterns = obj.getPatterns()
-
         print("Total number of Spatial Frequent Patterns:", len(spatialFrequentPatterns))
-
-        obj.savePatterns("outFile")
-
+        obj.save("outFile")
         memUSS = obj.getMemoryUSS()
-
         print("Total Memory in USS:", memUSS)
-
         memRSS = obj.getMemoryRSS()
-
         print("Total Memory in RSS", memRSS)
-
         run = obj.getRuntime()
-
         print("Total ExecutionTime in seconds:", run)
-
-
     Credits:
     -------
         The complete program was written by Yudai Masu under the supervision of Professor Rage Uday Kiran.
@@ -291,12 +266,6 @@ class FSPGrowth(_ab._spatialFrequentPatterns):
     _neighbourList = {}
     _fpList = []
 
-    '''def __init__(self, iFile, nFile, minSup, sep):
-        self.iFile = iFile
-        self.nFile = nFile
-        self.minSup = minSup
-        self.sep = sep'''
-
     def _readDatabase(self):
         """
         Read input file and neighborhood file
@@ -366,15 +335,6 @@ class FSPGrowth(_ab._spatialFrequentPatterns):
                 except IOError:
                     print("File Not Found2")
                     quit()
-        '''with open(self.nFile, "r") as nf:
-            for line in nf:
-                l = line.rstrip().split('\t')
-                key = tuple(l[0].rstrip().split(' '))
-                for i in range(len(l)):
-                    if i == 0:
-                        self.neighbourList[key] = []
-                    else:
-                        self.neighbourList[key].append(tuple(l[i].rstrip().split(' ')))'''
 
     def _getFrequentItems(self):
         """
@@ -426,11 +386,12 @@ class FSPGrowth(_ab._spatialFrequentPatterns):
         self._startTime = _ab._time.time()
         self._finalPatterns = {}
         self._readDatabase()
+        print(len(self._Database), len(self._neighbourList))
         self._minSup = self._convert(self._minSup)
         self._getFrequentItems()
         self._sortTransaction()
         _FPTree = self._createFPTree()
-        self._finalPatterns = (dict(_FPTree.mining(self._minSup, self._neighbourList)))
+        self._finalPatterns.update(dict(_FPTree.mining(self._minSup, self._neighbourList)))
         self._endTime = _ab._time.time()
         process = _ab._psutil.Process(_ab._os.getpid())
         self._memoryUSS = float()
@@ -439,7 +400,6 @@ class FSPGrowth(_ab._spatialFrequentPatterns):
         self._memoryRSS = process.memory_info().rss
         print("Frequent Spatial Patterns successfully generated using FSPGrowth")
 
-
     def getMemoryUSS(self):
         """Total amount of USS memory consumed by the mining process will be retrieved from this function
         :return: returning USS memory consumed by the mining process
@@ -466,20 +426,18 @@ class FSPGrowth(_ab._spatialFrequentPatterns):
 
     def getPatternsAsDataFrame(self):
         """Storing final frequent patterns in a dataframe
-
         :return: returning frequent patterns in a dataframe
-
         :rtype: pd.DataFrame
         """
 
         dataframe = {}
         data = []
         for a, b in self._finalPatterns.items():
-            data.append([a, b])
+            data.append([a.replace('\t', ' '), b])
             dataframe = _ab._pd.DataFrame(data, columns=['Patterns', 'Support'])
         return dataframe
 
-    def savePatterns(self, oFile):
+    def save(self, oFile):
         """
         Complete set of frequent patterns will be loaded in to a output file
         :param oFile: name of the output file
@@ -488,7 +446,7 @@ class FSPGrowth(_ab._spatialFrequentPatterns):
         self._oFile = oFile
         writer = open(self._oFile, 'w+')
         for x, y in self._finalPatterns.items():
-            s1 = x + ":" + str(y)
+            s1 = x.strip() + ":" + str(y)
             writer.write("%s \n" % s1)
 
     def getPatterns(self):
@@ -497,58 +455,29 @@ class FSPGrowth(_ab._spatialFrequentPatterns):
         :return: returning frequent patterns
         :rtype: dict
         """
+
         return self._finalPatterns
 
-    '''def savePatterns(self):
-        """
-        Complete set of frequent patterns will be loaded in to a output file
-
-        """
-        s = ""
-        s1 = ""
-        writer = open(self.oFile, 'w+')
-        for x, y in self.finalPatterns.items():
-            if type(x[0]) == str:
-                s1 = "Point(" + x[0] + " " + x[1] + ")" + " : " + str(y) + "\n"
-            else:
-                for point in x:
-                    s = "Point(" + str(point[0]) + " " + str(point[1]) + ")" + "\t"
-                    s1 += s
-                s1 += ": " + str(y) + "\n"
-            writer.write(s1)
-            s = ""
-            s1 = ""
-    '''
+    def printResults(self):
+        print("Total number of Spatial Frequent Patterns:", len(self.getPatterns()))
+        print("Total Memory in USS:", self.getMemoryUSS())
+        print("Total Memory in RSS", self.getMemoryRSS())
+        print("Total ExecutionTime in ms:",  self.getRuntime())
 
 
 if __name__ == "__main__":
-    ap = str()
+    _ap = str()
     if len(_ab._sys.argv) == 5 or len(_ab._sys.argv) == 6:
         if len(_ab._sys.argv) == 6:
-            ap = FSPGrowth(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4], _ab._sys.argv[5])
+            _ap = FSPGrowth(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4], _ab._sys.argv[5])
         if len(_ab._sys.argv) == 5:
-            ap = FSPGrowth(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4])
-        ap.startMine()
-        spatialFrequentPatterns = ap.getPatterns()
-        print("Total number of Spatial Frequent Patterns:", len(spatialFrequentPatterns))
-        ap.savePatterns(_ab._sys.argv[2])
-        memUSS = ap.getMemoryUSS()
-        print("Total Memory in USS:", memUSS)
-        memRSS = ap.getMemoryRSS()
-        print("Total Memory in RSS", memRSS)
-        run = ap.getRuntime()
-        print("Total ExecutionTime in seconds:", run)
+            _ap = FSPGrowth(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4])
+        _ap.startMine()
+        print("Total number of Spatial Frequent Patterns:", len(_ap.getPatterns()))
+        _ap.save(_ab._sys.argv[2])
+        print("Total Memory in USS:", _ap.getMemoryUSS())
+        print("Total Memory in RSS", _ap.getMemoryRSS())
+        print("Total ExecutionTime in seconds:", _ap.getRuntime())
     else:
-        ap = FSPGrowth('/Users/Likhitha/Downloads/Datasets/T10I4D200K.txt',
-                       '/Users/Likhitha/Downloads/Datasets/t10_neighbours', 2000, ' ')
-        ap.startMine()
-        spatialFrequentPatterns = ap.getPatterns()
-        print("Total number of Spatial Frequent Patterns:", len(spatialFrequentPatterns))
-        ap.savePatterns('/Users/Likhitha/Downloads/output')
-        memUSS = ap.getMemoryUSS()
-        print("Total Memory in USS:", memUSS)
-        memRSS = ap.getMemoryRSS()
-        print("Total Memory in RSS", memRSS)
-        run = ap.getRuntime()
-        print("Total ExecutionTime in seconds:", run)
         print("Error! The number of input parameters do not match the total number of parameters provided")
+
