@@ -41,7 +41,7 @@ class SpatialECLAT(_ab._spatialFrequentPatterns):
             Mining process will start from here
         getPatterns()
             Complete set of patterns will be retrieved with this function
-        savePatterns(oFile)
+        save(oFile)
             Complete set of frequent patterns will be loaded in to a output file
         getPatternsAsDataFrame()
             Complete set of frequent patterns will be loaded in to a dataframe
@@ -94,7 +94,7 @@ class SpatialECLAT(_ab._spatialFrequentPatterns):
 
         print("Total number of Spatial Frequent Patterns:", len(spatialFrequentPatterns))
 
-        obj.savePatterns("outFile")
+        obj.save("outFile")
 
         memUSS = obj.getMemoryUSS()
 
@@ -164,6 +164,7 @@ class SpatialECLAT(_ab._spatialFrequentPatterns):
                 except IOError:
                     print("File Not Found")
                     quit()
+
     # function to get frequent one pattern
     def _frequentOneItem(self):
         """Generating one frequent patterns"""
@@ -207,7 +208,7 @@ class SpatialECLAT(_ab._spatialFrequentPatterns):
 
         temp = []
         for ite in iList.keys():
-            ite = [int(i) for i in ite.strip('[]').split(',')]
+            ite = [int(i) for i in ite.strip('[]').split('\t')]
             temp.append(ite)
             # print(sorted(temp))
         return sorted(temp)
@@ -337,7 +338,6 @@ class SpatialECLAT(_ab._spatialFrequentPatterns):
         self._mapNeighbours()
         self._finalPatterns = {}
         self._frequentOneItem()
-        #print(len(self._finalPatterns))
         frequentSet = self._generateSpatialFrequentPatterns(self._finalPatterns)
         for x, y in frequentSet.items():
             if x not in self._finalPatterns:
@@ -395,11 +395,17 @@ class SpatialECLAT(_ab._spatialFrequentPatterns):
         dataFrame = {}
         data = []
         for a, b in self._finalPatterns.items():
-            data.append([a, b])
+            pat = str()
+            if type(a) == str:
+                pat = a
+            if type(a) == list:
+                for i in a:
+                    pat = pat + a + ' '
+            data.append([pat.strip(), b])
             dataFrame = _ab._pd.DataFrame(data, columns=['Patterns', 'Support'])
         return dataFrame
 
-    def savePatterns(self, outFile):
+    def save(self, outFile):
         """Complete set of frequent patterns will be loaded in to a output file
 
         :param outFile: name of the output file
@@ -408,10 +414,13 @@ class SpatialECLAT(_ab._spatialFrequentPatterns):
         self._oFile = outFile
         writer = open(self._oFile, 'w+')
         for x, y in self._finalPatterns.items():
-            pat = ""
-            for i in x:
-                pat += str(i) + " "
-            patternsAndSupport = pat + ": " + str(len(y))
+            pat = str()
+            if type(x) == str:
+                pat = x 
+            if type(x) == list:
+                for i in x:
+                    pat = pat + x + '\t'
+            patternsAndSupport = pat.strip() + ":" + str(len(y))
             writer.write("%s \n" % patternsAndSupport)
 
     def getPatterns(self):
@@ -422,35 +431,25 @@ class SpatialECLAT(_ab._spatialFrequentPatterns):
         """
         return self._finalPatterns
 
+    def printResults(self):
+        print("Total number of Spatial Frequent Patterns:", len(self.getPatterns()))
+        print("Total Memory in USS:", self.getMemoryUSS())
+        print("Total Memory in RSS", self.getMemoryRSS())
+        print("Total ExecutionTime in ms:",  self.getRuntime())
+
 
 if __name__ == "__main__":
-    ap = str()
+    _ap = str()
     if len(_ab._sys.argv) == 5 or len(_ab._sys.argv) == 6:
         if len(_ab._sys.argv) == 6:
-            ap = SpatialECLAT(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4], _ab._sys.argv[5])
+            _ap = SpatialECLAT(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4], _ab._sys.argv[5])
         if len(_ab._sys.argv) == 5:
-            ap = SpatialECLAT(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4])
-        ap.startMine()
-        spatialFrequentPatterns = ap.getPatterns()
-        print("Total number of Spatial Frequent Patterns:", len(spatialFrequentPatterns))
-        ap.savePatterns(_ab._sys.argv[2])
-        memUSS = ap.getMemoryUSS()
-        print("Total Memory in USS:", memUSS)
-        memRSS = ap.getMemoryRSS()
-        print("Total Memory in RSS", memRSS)
-        run = ap.getRuntime()
-        print("Total ExecutionTime in seconds:", run)
+            _ap = SpatialECLAT(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4])
+        _ap.startMine()
+        print("Total number of Spatial Frequent Patterns:", len(_ap.getPatterns()))
+        _ap.save(_ab._sys.argv[2])
+        print("Total Memory in USS:", _ap.getMemoryUSS())
+        print("Total Memory in RSS", _ap.getMemoryRSS())
+        print("Total ExecutionTime in seconds:", _ap.getRuntime())
     else:
-        ap = SpatialECLAT('/Users/Likhitha/Downloads/Datasets/T10I4D200K.txt',
-                       '/Users/Likhitha/Downloads/Datasets/t10_neighbours', 1000, ' ')
-        ap.startMine()
-        spatialFrequentPatterns = ap.getPatterns()
-        print("Total number of Spatial Frequent Patterns:", len(spatialFrequentPatterns))
-        ap.savePatterns('/Users/Likhitha/Downloads/output')
-        memUSS = ap.getMemoryUSS()
-        print("Total Memory in USS:", memUSS)
-        memRSS = ap.getMemoryRSS()
-        print("Total Memory in RSS", memRSS)
-        run = ap.getRuntime()
-        print("Total ExecutionTime in seconds:", run)
         print("Error! The number of input parameters do not match the total number of parameters provided")
