@@ -221,7 +221,7 @@ class FCPGrowth(_ab._corelatedFuzzyFrequentPatterns):
             Mining process will startTime from here
         getPatterns()
             Complete set of patterns will be retrieved with this function
-        savePatterns(oFile)
+        save(oFile)
             Complete set of frequent patterns will be loaded in to a output file
         getPatternsAsDataFrame()
             Complete set of frequent patterns will be loaded in to a dataframe
@@ -269,7 +269,7 @@ class FCPGrowth(_ab._corelatedFuzzyFrequentPatterns):
 
         print("Total number of Correlated Fuzzy Frequent Patterns:", len(correlatedFuzzyFrequentPatterns))
 
-        obj.savePatterns("output")
+        obj.save("output")
 
         memUSS = obj.getMemoryUSS()
 
@@ -301,8 +301,8 @@ class FCPGrowth(_ab._corelatedFuzzyFrequentPatterns):
     _memoryRSS = float()
     _Database = []
 
-    def __init__(self, iFile, minSup, ratio, sep="\t"):
-        super().__init__(iFile, minSup, ratio, sep)
+    def __init__(self, iFile, minSup, minAllConf, sep="\t"):
+        super().__init__(iFile, minSup, minAllConf, sep)
         self._temp = {}
         self._mapItemRegionSum = {}
         self._itemsCnt = 0
@@ -325,7 +325,7 @@ class FCPGrowth(_ab._corelatedFuzzyFrequentPatterns):
         """
         compare = self._mapItemSum[o1.item] - self._mapItemSum[o2.item]
         if compare == 0:
-            return o1.item - o2.item
+            return int(o1.item) - int(o2.item)
         else:
             return compare
 
@@ -622,10 +622,10 @@ class FCPGrowth(_ab._corelatedFuzzyFrequentPatterns):
         self._itemsCnt += 1
         res = ""
         for i in range(0, prefixLen):
-            res += str(prefix[i].item) + "." + str(prefix[i].region) + ' '
+            res += str(prefix[i].item) + "." + str(prefix[i].region) + '\t'
         res += str(item.item) + "." + str(item.region)
-        res1 = str(item.sumIUtil) + " : " + str(ratio) + "\n"
-        self._finalPatterns[res] = res1
+        #res1 = str(item.sumIUtil) + " : " + str(ratio) + "\n"
+        self._finalPatterns[res] = [item.sumIUtil, ratio]
 
     def getPatterns(self):
         """ Function to send the set of frequent patterns after completion of the mining process
@@ -645,11 +645,11 @@ class FCPGrowth(_ab._corelatedFuzzyFrequentPatterns):
         dataframe = {}
         data = []
         for a, b in self._finalPatterns.items():
-            data.append([a, b])
-            dataframe = _ab._pd.DataFrame(data, columns=['Patterns', 'Support'])
+            data.append([a.replace('\t', ' '), b[0], b[1]])
+            dataframe = _ab._pd.DataFrame(data, columns=['Patterns', 'Support', 'Confidence'])
         return dataframe
 
-    def savePatterns(self, outFile):
+    def save(self, outFile):
         """Complete set of frequent patterns will be loaded in to a output file
 
         :param outFile: name of the output file
@@ -658,26 +658,28 @@ class FCPGrowth(_ab._corelatedFuzzyFrequentPatterns):
         self._oFile = outFile
         writer = open(self._oFile, 'w+')
         for x, y in self._finalPatterns.items():
-            patternsAndSupport = str(x) + " : " + str(y)
+            patternsAndSupport = x.strip() + ":" + str(y[0]) + ":" + str(y[1])
             writer.write("%s \n" % patternsAndSupport)
 
+    def printResults(self):
+        print("Total number of Fuzzy Correlated Patterns:", len(self.getPatterns()))
+        print("Total Memory in USS:", self.getMemoryUSS())
+        print("Total Memory in RSS", self.getMemoryRSS())
+        print("Total ExecutionTime in ms:",  self.getRuntime())
+
 
 if __name__ == "__main__":
-    ap = str()
+    _ap = str()
     if len(_ab._sys.argv) == 5 or len(_ab._sys.argv) == 6:
         if len(_ab._sys.argv) == 6:
-            ap = FCPGrowth(_ab._sys.argv[1], _ab._sys.argv[3], float(_ab._sys.argv[4]), _ab._sys.argv[5])
+            _ap = FCPGrowth(_ab._sys.argv[1], _ab._sys.argv[3], float(_ab._sys.argv[4]), _ab._sys.argv[5])
         if len(_ab._sys.argv) == 5:
-            ap = FCPGrowth(_ab._sys.argv[1], _ab._sys.argv[3], float(_ab._sys.argv[4]))
-        ap.startMine()
-        fuzzycorrelatedFrequentPatterns = ap.getPatterns()
-        print("Total number of Fuzzy-Frequent Patterns:", len(fuzzycorrelatedFrequentPatterns))
-        ap.savePatterns(_ab._sys.argv[2])
-        memUSS = ap.getMemoryUSS()
-        print("Total Memory in USS:", memUSS)
-        memRSS = ap.getMemoryRSS()
-        print("Total Memory in RSS", memRSS)
-        run = ap.getRuntime()
-        print("Total ExecutionTime in seconds:", run)
+            _ap = FCPGrowth(_ab._sys.argv[1], _ab._sys.argv[3], float(_ab._sys.argv[4]))
+        _ap.startMine()
+        print("Total number of Fuzzy Correlated Patterns:", len(_ap.getPatterns()))
+        _ap.save(_ab._sys.argv[2])
+        print("Total Memory in USS:",  _ap.getMemoryUSS())
+        print("Total Memory in RSS",  _ap.getMemoryRSS())
+        print("Total ExecutionTime in seconds:", _ap.getRuntime())
     else:
         print("Error! The number of input parameters do not match the total number of parameters provided")
