@@ -25,7 +25,6 @@
 #
 #      You should have received a copy of the GNU General Public License
 #      along with this program.  If not, see <https://www.gnu.org/licenses/>.
-import re
 
 from PAMI.fuzzyFrequentPatterns.basic import abstract as _ab
 
@@ -50,7 +49,7 @@ class _FFList:
             Method to add an element to this fuzzy list and update the sums at the same time.
 
         printElement(e)
-            Method to print elements            
+            Method to print elements
 
     """
 
@@ -107,7 +106,7 @@ class _Regions:
     ----------
             low : int
                 low region value
-            middle: int 
+            middle: int
                 middle region value
             high : int
                 high region values
@@ -118,11 +117,11 @@ class _Regions:
         self.middle = 0
         self.high = 0
         if regionsNumber == 3:  # if we have 3 regions
-            if 0 < quantity <=1:
+            if 0 < quantity <= 1:
                 self.low = 1
                 self.high = 0
                 self.middle = 0
-            elif 1< quantity <= 6:
+            elif 1 < quantity <= 6:
                 self.low = float((6 - quantity) / 5)
                 self.middle = float((quantity - 1) / 5)
                 self.high = 0
@@ -148,7 +147,7 @@ class _Pair:
 
 class FFIMiner(_ab._fuzzyFrequentPattenrs):
     """
-        Fuzzy Frequent  Pattern-Miner is desired to find all  frequent fuzzy patterns which is on-trivial and challenging problem 
+        Fuzzy Frequent  Pattern-Miner is desired to find all  frequent fuzzy patterns which is on-trivial and challenging problem
         to its huge search space.we are using efficient pruning techniques to reduce the search space.
     Reference :
     ---------
@@ -192,7 +191,7 @@ class FFIMiner(_ab._fuzzyFrequentPattenrs):
             Mining process will start from here
         getPatterns()
             Complete set of patterns will be retrieved with this function
-        savePatterns(oFile)
+        save(oFile)
             Complete set of frequent patterns will be loaded in to a output file
         getPatternsAsDataFrame()
             Complete set of frequent patterns will be loaded in to a dataframe
@@ -201,7 +200,7 @@ class FFIMiner(_ab._fuzzyFrequentPattenrs):
         getMemoryRSS()
             Total amount of RSS memory consumed by the mining process will be retrieved from this function
         getRuntime()
-            Total amount of runtime taken by the mining process will be retrieved from this function            
+            Total amount of runtime taken by the mining process will be retrieved from this function
         convert(value):
             To convert the given user specified value
         compareItems(o1, o2)
@@ -214,7 +213,7 @@ class FFIMiner(_ab._fuzzyFrequentPattenrs):
             To find element with same tid as given
         WriteOut(prefix, prefixLen, item, sumIUtil)
             To Store the patten
-    
+
     Executing the code on terminal :
     -------
         Format:
@@ -229,7 +228,7 @@ class FFIMiner(_ab._fuzzyFrequentPattenrs):
 
     Sample run of importing the code:
     -------------------------------
-        
+
         from PAMI.fuzzyFrequentPatterns import FFIMiner as alg
 
         obj = alg.FFIMiner("input.txt", 2)
@@ -240,7 +239,7 @@ class FFIMiner(_ab._fuzzyFrequentPattenrs):
 
         print("Total number of Fuzzy Frequent Patterns:", len(fuzzyFrequentPatterns))
 
-        obj.savePatterns("outputFile")
+        obj.save("outputFile")
 
         memUSS = obj.getMemoryUSS()
 
@@ -349,8 +348,7 @@ class FFIMiner(_ab._fuzzyFrequentPattenrs):
                 try:
                     with open(self._iFile, 'r', encoding='utf-8') as f:
                         for line in f:
-                            # line = line.split("\n")[0]
-                            line = line.strip()
+                            line = line.split("\n")[0]
                             parts = line.split(":")
                             parts[0] = parts[0].strip()
                             parts[2] = parts[2].strip()
@@ -363,7 +361,7 @@ class FFIMiner(_ab._fuzzyFrequentPattenrs):
                     quit()
 
     def startMine(self):
-        """ 
+        """
           fuzzy-Frequent pattern mining process will start from here
         """
         self._startTime = _ab._time.time()
@@ -373,10 +371,7 @@ class FFIMiner(_ab._fuzzyFrequentPattenrs):
             quantities = self._fuzzyValues[line]
             self._dbLen += 1
             for i in range(0, len(items)):
-                if quantities[i] != '' and quantities[i] != '...':
-                    regions = _Regions(float(quantities[i]), 3)
-                else:
-                    regions = _Regions(float(0), 3)
+                regions = _Regions(float(quantities[i]), 3)
                 item = items[i]
                 if item in self._mapItemsLowSum.keys():
                     low = self._mapItemsLowSum[item]
@@ -399,7 +394,7 @@ class FFIMiner(_ab._fuzzyFrequentPattenrs):
         listOfffilist = []
         mapItemsToFFLIST = {}
         self._minSup = self._convert(self._minSup)
-        #minSup = self.minSup
+        # minSup = self.minSup
         for item1 in self._mapItemsLowSum.keys():
             item = item1
             low = self._mapItemsLowSum[item]
@@ -427,10 +422,7 @@ class FFIMiner(_ab._fuzzyFrequentPattenrs):
             for i in range(0, len(items)):
                 pair = _Pair()
                 pair.item = items[i]
-                if quantities[i] != '' and quantities[i] != '...':
-                    regions = _Regions(float(quantities[i]), 3)
-                else:
-                    regions = _Regions(float(0), 3)
+                regions = _Regions(float(quantities[i]), 3)
                 item = pair.item
                 if self._mapItemSum[item] >= self._minSup:
                     if self._mapItemRegions[pair.item] == "L":
@@ -470,7 +462,7 @@ class FFIMiner(_ab._fuzzyFrequentPattenrs):
         :type prefixLen: int
         :param FSFIM: the Fuzzy list of prefix itemSets
         :type FSFIM: list
-        :param minSup: the minimum support of 
+        :param minSup: the minimum support of
         :type minSup:int
         """
         for i in range(0, len(FSFIM)):
@@ -572,9 +564,9 @@ class FFIMiner(_ab._fuzzyFrequentPattenrs):
         self._itemsCnt += 1
         res = ""
         for i in range(0, prefixLen):
-            res += str(prefix[i]) + "." + str(self._mapItemRegions[prefix[i]]) + " "
+            res += str(prefix[i]) + "." + str(self._mapItemRegions[prefix[i]]) + "\t"
         res += str(item) + "." + str(self._mapItemRegions.get(item))
-        res1 = str(sumIUtil) + "\n"
+        res1 = str(sumIUtil)
         self._finalPatterns[res] = res1
 
     def getPatternsAsDataFrame(self):
@@ -587,7 +579,7 @@ class FFIMiner(_ab._fuzzyFrequentPattenrs):
         dataFrame = {}
         data = []
         for a, b in self._finalPatterns.items():
-            data.append([a, b])
+            data.append([a.replace('\t', ' '), b])
             dataFrame = _ab._pd.DataFrame(data, columns=['Patterns', 'Support'])
         return dataFrame
 
@@ -599,7 +591,7 @@ class FFIMiner(_ab._fuzzyFrequentPattenrs):
         """
         return self._finalPatterns
 
-    def savePatterns(self, outFile):
+    def save(self, outFile):
         """Complete set of frequent patterns will be loaded in to a output file
 
         :param outFile: name of the output file
@@ -608,43 +600,29 @@ class FFIMiner(_ab._fuzzyFrequentPattenrs):
         self._oFile = outFile
         writer = open(self._oFile, 'w+')
         for x, y in self._finalPatterns.items():
-            patternsAndSupport = str(x) + " : " + str(y)
-            writer.write("%s" % patternsAndSupport)
+            patternsAndSupport = x.strip() + ":" + str(y)
+            writer.write("%s \n" % patternsAndSupport)
+
+    def printResults(self):
+        print("Total number of Fuzzy Frequent Patterns:", len(self.getPatterns()))
+        print("Total Memory in USS:", self.getMemoryUSS())
+        print("Total Memory in RSS", self.getMemoryRSS())
+        print("Total ExecutionTime in seconds:", self.getRuntime())
 
 
 if __name__ == "__main__":
-    ap = str()
+    _ap = str()
     if len(_ab._sys.argv) == 4 or len(_ab._sys.argv) == 5:
         if len(_ab._sys.argv) == 5:
-            ap = FFIMiner(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4])
+            _ap = FFIMiner(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4])
         if len(_ab._sys.argv) == 4:
-           ap = FFIMiner(_ab._sys.argv[1], _ab._sys.argv[3])
-        ap.startMine()
-        fuzzyFrequentPatterns = ap.getPatterns()
-        print("Total number of Fuzzy-Frequent Patterns:", len(fuzzyFrequentPatterns))
-        ap.savePatterns(_ab._sys.argv[2])
-        memUSS = ap.getMemoryUSS()
-        print("Total Memory in USS:", memUSS)
-        memRSS = ap.getMemoryRSS()
-        print("Total Memory in RSS", memRSS)
-        run = ap.getRuntime()
-        print("Total ExecutionTime in seconds:", run)
+            _ap = FFIMiner(_ab._sys.argv[1], _ab._sys.argv[3])
+        _ap.startMine()
+        print("Total number of Fuzzy-Frequent Patterns:", len(_ap.getPatterns()))
+        _ap.save(_ab._sys.argv[2])
+        print("Total Memory in USS:", _ap.getMemoryUSS())
+        print("Total Memory in RSS", _ap.getMemoryRSS())
+        print("Total ExecutionTime in seconds:", _ap.getRuntime())
     else:
-        # l = [1800, 1900, 2000, 2200, 2400]
-        # for i in l:
-        #     ap = FFIMiner('/Users/Likhitha/Downloads/mushroom_utility_spmf.txt', i, ' ')
-        #     ap.startMine()
-        #     fuzzycorrelatedFrequentPatterns = ap.getPatterns()
-        #     print("Total number of Fuzzy-Frequent Patterns:", len(fuzzycorrelatedFrequentPatterns))
-        #     ap.savePatterns('/Users/Likhitha/Downloads/output')
-        #     memUSS = ap.getMemoryUSS()
-        #     print("Total Memory in USS:", memUSS)
-        #     memRSS = ap.getMemoryRSS()
-        #     print("Total Memory in RSS", memRSS)
-        #     run = ap.getRuntime()
-        #     print("Total ExecutionTime in seconds:", run)
-        # print("Error! The number of input parameters do not match the total number of parameters provided")
-        threshold = [30, 60, 90, 120, 250]
-        for i in threshold:
-            obj = FFIMiner('pm25_1_2021-01-01_2021-01-31.csv', i)
-            obj.startMine()
+        print("Error! The number of input parameters do not match the total number of parameters provided")
+
