@@ -151,6 +151,12 @@ class FFSPMiner(_ab._fuzzySpatialFrequentPatterns):
         which is on-trivial and challenging problem to its huge search space.we are using efficient pruning
          techniques to reduce the search space.
 
+    Reference:
+    ---------
+        Reference: P. Veena, B. S. Chithra, R. U. Kiran, S. Agarwal and K. Zettsu, "Discovering Fuzzy Frequent
+        Spatial Patterns in Large Quantitative Spatiotemporal databases," 2021 IEEE International Conference on Fuzzy Systems
+        (FUZZ-IEEE), 2021, pp. 1-8, doi: 10.1109/FUZZ45933.2021.9494594.
+
     Attributes :
     ----------
         iFile : file
@@ -191,7 +197,7 @@ class FFSPMiner(_ab._fuzzySpatialFrequentPatterns):
             Mining process will start from here
         getPatterns()
             Complete set of patterns will be retrieved with this function
-        savePatterns(oFile)
+        save(oFile)
             Complete set of frequent patterns will be loaded in to a output file
         getPatternsAsDataFrame()
             Complete set of frequent patterns will be loaded in to a dataframe
@@ -239,7 +245,7 @@ class FFSPMiner(_ab._fuzzySpatialFrequentPatterns):
 
         print("Total number of fuzzy frequent spatial patterns:", len(fuzzySpatialFrequentPatterns))
 
-        obj.savePatterns("outputFile")
+        obj.save("outputFile")
 
         memUSS = obj.getMemoryUSS()
 
@@ -334,6 +340,8 @@ class FFSPMiner(_ab._fuzzySpatialFrequentPatterns):
                     line = line.decode("utf-8")
                     line = line.split("\n")[0]
                     parts = line.split(":")
+                    parts[0] = parts[0].strip()
+                    parts[2] = parts[2].strip()
                     items = parts[0].split(self._sep)
                     quantities = parts[2].split(self._sep)
                     self.transactions.append([x for x in items])
@@ -344,10 +352,12 @@ class FFSPMiner(_ab._fuzzySpatialFrequentPatterns):
                         for line in f:
                             line = line.split("\n")[0]
                             parts = line.split(":")
+                            parts[0] = parts[0].strip()
+                            parts[2] = parts[2].strip()
                             items = parts[0].split(self._sep)
                             quantities = parts[2].split(self._sep)
-                            self.transactions.append([x for x in items])
-                            self.fuzzyValues.append([x for x in quantities])
+                            self._transactions.append([x for x in items])
+                            self._fuzzyValues.append([x for x in quantities])
                 except IOError:
                     print("File Not Found")
                     quit()
@@ -381,7 +391,7 @@ class FFSPMiner(_ab._fuzzySpatialFrequentPatterns):
                     self._mapItemNeighbours[item] = neigh1
             else:
                 try:
-                    with open(self._iFile, 'r', encoding='utf-8') as f:
+                    with open(self._nFile, 'r', encoding='utf-8') as f:
                         for line in f:
                             line = line.split("\n")[0]
                             parts = [i.rstrip() for i in line.split(self._sep)]
@@ -402,9 +412,9 @@ class FFSPMiner(_ab._fuzzySpatialFrequentPatterns):
         self._creatingItemSets()
         self._finalPatterns = {}
         self._mapNeighbours()
-        for line in range(len(self.transactions)):
-            items = self.transactions[line]
-            quantities = self.fuzzyValues[line]
+        for line in range(len(self._transactions)):
+            items = self._transactions[line]
+            quantities = self._fuzzyValues[line]
             self._dbLen += 1
             for i in range(0, len(items)):
                 regions = _Regions(int(quantities[i]), 3)
@@ -450,9 +460,9 @@ class FFSPMiner(_ab._fuzzySpatialFrequentPatterns):
                 listOfFFList.append(fuList)
         listOfFFList.sort(key=_ab._functools.cmp_to_key(self._compareItems))
         tid = 0
-        for line in range(len(self.transactions)):
-            items = self.transactions[line]
-            quantities = self.fuzzyValues[line]
+        for line in range(len(self._transactions)):
+            items = self._transactions[line]
+            quantities = self._fuzzyValues[line]
             revisedTransaction = []
             for i in range(0, len(items)):
                 pair = _Pair()
@@ -624,7 +634,7 @@ class FFSPMiner(_ab._fuzzySpatialFrequentPatterns):
         self._itemsCnt += 1
         res = ""
         for i in range(0, prefixLen):
-            res += str(prefix[i]) + "." + str(self._mapItemRegions[prefix[i]]) + " "
+            res += str(prefix[i]) + "." + str(self._mapItemRegions[prefix[i]]) + "\t"
         res += str(item) + "." + str(self._mapItemRegions.get(item))
         res1 = str(sumIUtil)
         self._finalPatterns[res] = res1
@@ -639,7 +649,7 @@ class FFSPMiner(_ab._fuzzySpatialFrequentPatterns):
         dataFrame = {}
         data = []
         for a, b in self._finalPatterns.items():
-            data.append([a, b])
+            data.append([a.replace('\t', ' '), b])
             dataFrame = _ab._pd.DataFrame(data, columns=['Patterns', 'Support'])
         return dataFrame
 
@@ -651,7 +661,7 @@ class FFSPMiner(_ab._fuzzySpatialFrequentPatterns):
         """
         return self._finalPatterns
 
-    def savePatterns(self, outFile):
+    def save(self, outFile):
         """Complete set of frequent patterns will be loaded in to a output file
 
         :param outFile: name of the output file
@@ -660,26 +670,28 @@ class FFSPMiner(_ab._fuzzySpatialFrequentPatterns):
         self.oFile = outFile
         writer = open(self.oFile, 'w+')
         for x, y in self._finalPatterns.items():
-            patternsAndSupport = str(x) + " : " + str(y)
+            patternsAndSupport = x.strip() + " : " + str(y)
             writer.write("%s \n" % patternsAndSupport)
 
+    def printResults(self):
+        print("Total number of Spatial Fuzzy Frequent Patterns:", len(self.getPatterns()))
+        print("Total Memory in USS:", self.getMemoryUSS())
+        print("Total Memory in RSS", self.getMemoryRSS())
+        print("Total ExecutionTime in seconds:", self.getRuntime())
+
 
 if __name__ == "__main__":
-    ap = str()
+    _ap = str()
     if len(_ab._sys.argv) == 5 or len(_ab._sys.argv) == 6:
         if len(_ab._sys.argv) == 6:
-            ap = FFSPMiner(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4], _ab._sys.argv[5])
+            _ap = FFSPMiner(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4], _ab._sys.argv[5])
         if len(_ab._sys.argv) == 5:
-            ap = FFSPMiner(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4])
-        ap.startMine()
-        fuzzySpatialFrequentPatterns = ap.getPatterns()
-        print("Total number of fuzzy frequent Spatial Patterns:", len(fuzzySpatialFrequentPatterns))
-        ap.savePatterns(_ab._sys.argv[2])
-        memUSS = ap.getMemoryUSS()
-        print("Total Memory in USS:", memUSS)
-        memRSS = ap.getMemoryRSS()
-        print("Total Memory in RSS", memRSS)
-        run = ap.getRuntime()
-        print("Total ExecutionTime in seconds:", run)
+            _ap = FFSPMiner(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4])
+        _ap.startMine()
+        print("Total number of Spatial Fuzzy Frequent  Patterns:", len(_ap.getPatterns()))
+        _ap.save(_ab._sys.argv[2])
+        print("Total Memory in USS:", _ap.getMemoryUSS())
+        print("Total Memory in RSS",  _ap.getMemoryRSS())
+        print("Total ExecutionTime in seconds:", _ap.getRuntime())
     else:
         print("Error! The number of input parameters do not match the total number of parameters provided")
