@@ -114,7 +114,7 @@ class _Regions:
     ----------
             low : int
                 low region value
-            middle: int 
+            middle: int
                 middle region value
             high : int
                 high region values
@@ -206,7 +206,7 @@ class FPFPMiner(_ab._fuzzyPeriodicFrequentPatterns):
             Mining process will start from here
         getPatterns()
             Complete set of patterns will be retrieved with this function
-        savePatterns(oFile)
+        save(oFile)
             Complete set of frequent patterns will be loaded in to a output file
         getPatternsAsDataFrame()
             Complete set of frequent patterns will be loaded in to a dataframe
@@ -215,7 +215,7 @@ class FPFPMiner(_ab._fuzzyPeriodicFrequentPatterns):
         getMemoryRSS()
             Total amount of RSS memory consumed by the mining process will be retrieved from this function
         getRuntime()
-            Total amount of runtime taken by the mining process will be retrieved from this function            
+            Total amount of runtime taken by the mining process will be retrieved from this function
         convert(value):
             To convert the given user specified value
         FSFIMining( prefix, prefixLen, fsFim, minSup)
@@ -226,7 +226,7 @@ class FPFPMiner(_ab._fuzzyPeriodicFrequentPatterns):
             To find element with same tid as given
         WriteOut(prefix, prefixLen, item, sumIUtil,period)
             To Store the patten
-    
+
     Executing the code on terminal :
     -------
         Format:
@@ -236,13 +236,13 @@ class FPFPMiner(_ab._fuzzyPeriodicFrequentPatterns):
         Examples:
         ------
             python3  FPFPMiner.py sampleTDB.txt output.txt 2 3 (minSup and maxPer will be considered in support count or frequency)
-        
+
             python3  FPFPMiner.py sampleTDB.txt output.txt 0.25 0.3 (minSup and maxPer will be considered in percentage of database)
                                         (will consider "\t" as separator)
-        
+
             python3  FPFPMiner.py sampleTDB.txt output.txt 2 3  ,(will consider ',' as separator)
-        
-    
+
+
     Sample run of importing the code:
     -------------------------------
 
@@ -256,7 +256,7 @@ class FPFPMiner(_ab._fuzzyPeriodicFrequentPatterns):
 
         print("Total number of Fuzzy Periodic Frequent Patterns:", len(periodicFrequentPatterns))
 
-        obj.savePatterns("output.txt")
+        obj.save("output.txt")
 
         memUSS = obj.getMemoryUSS()
 
@@ -269,7 +269,7 @@ class FPFPMiner(_ab._fuzzyPeriodicFrequentPatterns):
         run = obj.getRuntime()
 
         print("Total ExecutionTime in seconds:", run)
-        
+
     Credits:
     -------
             The complete program was written by Sai Chitra.B under the supervision of Professor Rage Uday Kiran.
@@ -335,7 +335,7 @@ class FPFPMiner(_ab._fuzzyPeriodicFrequentPatterns):
             else:
                 value = int(value)
         return value
-    
+
     def _creatingItemSets(self):
         data, self._transactions, self._fuzzyValues, ts = [], [], [], []
         if isinstance(self._iFile, _ab._pd.DataFrame):
@@ -351,30 +351,34 @@ class FPFPMiner(_ab._fuzzyPeriodicFrequentPatterns):
         if isinstance(self._iFile, str):
             if _ab._validators.url(self._iFile):
                 data = _ab._urlopen(self._iFile)
+                count = 0
                 for line in data:
                     line = line.decode("utf-8")
                     line = line.split("\n")[0]
                     parts = line.split(":")
-                    parts[1] = parts[1].strip()
-                    parts[3] = parts[3].strip()
-                    items = parts[1].split(self._sep)
-                    quantities = parts[3].split(self._sep)
-                    self._ts.append(int(parts[0]))
+                    parts[0] = parts[0].strip()
+                    parts[2] = parts[2].strip()
+                    items = parts[0].split(self._sep)
+                    quantities = parts[2].split(self._sep)
+                    self._ts.append(count)
                     self._transactions.append([x for x in items])
                     self._fuzzyValues.append([x for x in quantities])
+                    count += 1
             else:
                 try:
                     with open(self._iFile, 'r', encoding='utf-8') as f:
+                        count = 0
                         for line in f:
                             line = line.split("\n")[0]
                             parts = line.split(":")
-                            parts[1] = parts[1].strip()
-                            parts[3] = parts[3].strip()
-                            items = parts[1].split(self._sep)
-                            quantities = parts[3].split(self._sep)
-                            self._ts.append(int(parts[0]))
+                            parts[0] = parts[0].strip()
+                            parts[2] = parts[2].strip()
+                            items = parts[0].split(self._sep)
+                            quantities = parts[2].split(self._sep)
+                            self._ts.append(count)
                             self._transactions.append([x for x in items])
                             self._fuzzyValues.append([x for x in quantities])
+                            count += 1
                 except IOError:
                     print("File Not Found")
                     quit()
@@ -505,7 +509,7 @@ class FPFPMiner(_ab._fuzzyPeriodicFrequentPatterns):
         :type prefixLen: int
         :param fsFim: the Fuzzy list of prefix itemSets
         :type fsFim: list
-        :param minSup: the minimum support of 
+        :param minSup: the minimum support of
         :type minSup:int
         """
         for i in range(0, len(fsFim)):
@@ -609,10 +613,10 @@ class FPFPMiner(_ab._fuzzyPeriodicFrequentPatterns):
         self._itemsCnt += 1
         res = ""
         for i in range(0, prefixLen):
-            res += str(prefix[i]) + "." + str(self._mapItemRegions[prefix[i]]) + " "
+            res += str(prefix[i]) + "." + str(self._mapItemRegions[prefix[i]]) + "\t"
         res += str(item) + "." + str(self._mapItemRegions.get(item))
-        res1 = str(sumLUtil) + " : " + str(period) + "\n"
-        self._finalPatterns[res] = res1
+        #res1 = str(sumLUtil) + " : " + str(period)
+        self._finalPatterns[res] = [sumLUtil, period]
 
     def getPatternsAsDataFrame(self):
         """Storing final frequent patterns in a dataframe
@@ -624,8 +628,8 @@ class FPFPMiner(_ab._fuzzyPeriodicFrequentPatterns):
         dataFrame = {}
         data = []
         for a, b in self._finalPatterns.items():
-            data.append([a, b])
-            dataFrame = _ab._pd.DataFrame(data, columns=['Patterns', 'Support'])
+            data.append([a.replace('\t', ' '), b[0], b[1]])
+            dataFrame = _ab._pd.DataFrame(data, columns=['Patterns', 'Support', 'Periodicity'])
         return dataFrame
 
     def getPatterns(self):
@@ -636,7 +640,7 @@ class FPFPMiner(_ab._fuzzyPeriodicFrequentPatterns):
         """
         return self._finalPatterns
 
-    def savePatterns(self, outFile):
+    def save(self, outFile):
         """Complete set of frequent patterns will be loaded in to a output file
 
         :param outFile: name of the output file
@@ -645,26 +649,29 @@ class FPFPMiner(_ab._fuzzyPeriodicFrequentPatterns):
         self._oFile = outFile
         writer = open(self._oFile, 'w+')
         for x, y in self._finalPatterns.items():
-            patternsAndSupport = str(x) + " : " + str(y)
+            patternsAndSupport = x.strip() + ":" + str(y[0]) + ":" + str(y[1])
             writer.write("%s \n" % patternsAndSupport)
 
+    def printResults(self):
+        print("Total number of Fuzzy Periodic-Frequent Patterns:", len(self.getPatterns()))
+        print("Total Memory in USS:", self.getMemoryUSS())
+        print("Total Memory in RSS", self.getMemoryRSS())
+        print("Total ExecutionTime in seconds:", self.getRuntime())
+
 
 if __name__ == "__main__":
-    ap = str()
+    _ap = str()
     if len(_ab._sys.argv) == 5 or len(_ab._sys.argv) == 6:
         if len(_ab._sys.argv) == 6:  # to  include a user specified separator
-            ap = FPFPMiner(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4], _ab._sys.argv[5])
+            _ap = FPFPMiner(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4], _ab._sys.argv[5])
         if len(_ab._sys.argv) == 5:  # to consider "\t" as a separator
-            ap = FPFPMiner(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4])
-        ap.startMine()
-        periodicFrequentPatterns = ap.getPatterns()
-        print("Total number of Fuzzy Periodic Frequent Patterns:", len(periodicFrequentPatterns))
-        ap.savePatterns(_ab._sys.argv[2])
-        memUSS = ap.getMemoryUSS()
-        print("Total Memory in USS:", memUSS)
-        memRSS = ap.getMemoryRSS()
-        print("Total Memory in RSS", memRSS)
-        run = ap.getRuntime()
-        print("Total ExecutionTime in seconds:", run)
+            _ap = FPFPMiner(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4])
+        _ap.startMine()
+        print("Total number of Fuzzy Periodic-Frequent Patterns:", len(_ap.getPatterns()))
+        _ap.save(_ab._sys.argv[2])
+        print("Total Memory in USS:", _ap.getMemoryUSS())
+        print("Total Memory in RSS", _ap.getMemoryRSS())
+        print("Total ExecutionTime in seconds:", _ap.getRuntime())
     else:
         print("Error! The number of input parameters do not match the total number of parameters provided")
+
