@@ -196,10 +196,10 @@ class _Dataset:
             i = datasetPath.columns.values.tolist()
             if 'Transactions' in i:
                 data = datasetPath['Transactions'].tolist()
-            if 'utilities' in i:
-                utilities = datasetPath['utilities'].tolist()
-            if 'utilitySum' in i:
-                utilitySum = datasetPath['utilitySum'].tolist()
+            if 'Utilities' in i:
+                utilities = datasetPath['Utilities'].tolist()
+            if 'UtilitySum' in i:
+                utilitySum = datasetPath['UtilitySum'].tolist()
             for k in range(len(data)):
                 self.transactions.append(self.createTransaction(data[k], utilities[k], utilitySum[k]))
         if isinstance(datasetPath, str):
@@ -332,7 +332,7 @@ class HUFIM(_ab._utilityPatterns):
                 Mining process will start from here
         getPatterns()
                 Complete set of patterns will be retrieved with this function
-        savePatterns(oFile)
+        save(oFile)
                 Complete set of patterns will be loaded in to a output file
         getPatternsAsDataFrame()
                 Complete set of patterns will be loaded in to a dataframe
@@ -381,7 +381,7 @@ class HUFIM(_ab._utilityPatterns):
 
         print("Total number of high utility frequent Patterns:", len(Patterns))
 
-        obj.savePatterns("output")
+        obj.save("output")
 
         memUSS = obj.getMemoryUSS()
 
@@ -459,14 +459,10 @@ class HUFIM(_ab._utilityPatterns):
         self._useUtilityBinArrayToCalculateLocalUtilityFirstTime(self._dataset)
         self._minUtil = int(self._minUtil)
         self._minSup = self._convert(self._minSup)
-        #print("######################################")
-        #print("given minimum support is", self.minSup)
-        #print("given minimum utility is", self.minUtil)
         itemsToKeep = []
         for key in self._utilityBinArrayLU.keys():
             if self._utilityBinArrayLU[key] >= self._minUtil and self._singleItemSetsSupport[key] >= self._minSup:
                 itemsToKeep.append(key)
-        # sorting items in decreasing order of utilities
         itemsToKeep = sorted(itemsToKeep, key=lambda x: self._singleItemSetsUtility[x], reverse=True)
         currentName = 1
         for idx, item in enumerate(itemsToKeep):
@@ -649,12 +645,12 @@ class HUFIM(_ab._utilityPatterns):
          :type support: int
         """
         self._patternCount += 1
-        s1 = ""
+        s1 = str()
         for i in range(0, tempPosition+1):
             s1 += self._dataset.intToStr.get((self._temp[i]))
             if i != tempPosition:
-                s1 += " "
-        self._finalPatterns[s1] = str(utility) + ":" + str(support)
+                s1 += "\t"
+        self._finalPatterns[s1] = [utility, support]
 
     def _isEqual(self, transaction1, transaction2):
         """
@@ -787,8 +783,8 @@ class HUFIM(_ab._utilityPatterns):
         dataFrame = {}
         data = []
         for a, b in self._finalPatterns.items():
-            data.append([a, b])
-            dataFrame = _ab._pd.DataFrame(data, columns=['Patterns', 'Utility:Support'])
+            data.append([a.replace('\t', ' '), b[0], b[1]])
+            dataFrame = _ab._pd.DataFrame(data, columns=['Patterns', 'Utility', 'Support'])
 
         return dataFrame
     
@@ -800,7 +796,7 @@ class HUFIM(_ab._utilityPatterns):
         """
         return self._finalPatterns
 
-    def savePatterns(self, outFile):
+    def save(self, outFile):
         """Complete set of frequent patterns will be loaded in to a output file
 
         :param outFile: name of the output file
@@ -809,7 +805,7 @@ class HUFIM(_ab._utilityPatterns):
         self._oFile = outFile
         writer = open(self._oFile, 'w+')
         for x, y in self._finalPatterns.items():
-            patternsAndSupport = str(x) + " : " + str(y)
+            patternsAndSupport = x.strip() + ":" + str(y[0]) + ":" + str(y[1])
             writer.write("%s \n" % patternsAndSupport)
 
     def getMemoryUSS(self):
@@ -837,40 +833,26 @@ class HUFIM(_ab._utilityPatterns):
         :rtype: float
        """
         return self._endTime-self._startTime
-
+    
+    def printResults(self):
+        print("Total number of High Utility Frequent Patterns:", len(self.getPatterns()))
+        print("Total Memory in USS:", self.getMemoryUSS())
+        print("Total Memory in RSS", self.getMemoryRSS())
+        print("Total ExecutionTime in seconds:", self.getRuntime())
 
 if __name__ == '__main__':
-    ap = str()
+    _ap = str()
     if len(_ab._sys.argv) == 5 or len(_ab._sys.argv) == 6:
         if len(_ab._sys.argv) == 6:    #includes separator
-            ap = HUFIM(_ab._sys.argv[1], int(_ab._sys.argv[3]), float(_ab._sys.argv[4]), _ab._sys.argv[5])
+            _ap = HUFIM(_ab._sys.argv[1], int(_ab._sys.argv[3]), float(_ab._sys.argv[4]), _ab._sys.argv[5])
         if len(_ab._sys.argv) == 5:    #takes "\t" as a separator
-            ap = HUFIM(_ab._sys.argv[1], int(_ab._sys.argv[3]), float(_ab._sys.argv[4]))
-        ap.startMine()
-        patterns = ap.getPatterns()
-        print("Total number of High Utility Frequent Patterns:", ap._patternCount)
-        print("Total number of Candidate Patterns:", ap._candidateCount)
-        ap.savePatterns(_ab._sys.argv[2])
-        memUSS = ap.getMemoryUSS()
-        print("Total Memory in USS:", memUSS)
-        memRSS = ap.getMemoryRSS()
-        print("Total Memory in RSS", memRSS)
-        run = ap.getRuntime()
-        print("Total ExecutionTime in seconds:", run)
-        print("######################################")
+            _ap = HUFIM(_ab._sys.argv[1], int(_ab._sys.argv[3]), float(_ab._sys.argv[4]))
+        _ap.startMine()
+        print("Total number of High Utility Frequent Patterns:", len(_ap.getPatterns()))
+        _ap.save(_ab._sys.argv[2])
+        print("Total Memory in USS:", _ap.getMemoryUSS())
+        print("Total Memory in RSS", _ap.getMemoryRSS())
+        print("Total ExecutionTime in seconds:", _ap.getRuntime())
     else:
-        l = [2000, 5000, 40000]
-        for i in l:
-            ap = HUFIM('/Users/Likhitha/Downloads/mushroom_utility_SPMF.txt', i, 1000, ' ')
-            ap.startMine()
-            patterns = ap.getPatterns()
-            print("Total number of High Utility Frequent Patterns:", ap._patternCount)
-            print("Total number of Candidate Patterns:", ap._candidateCount)
-            ap.savePatterns('/Users/Likhitha/Downloads/output')
-            memUSS = ap.getMemoryUSS()
-            print("Total Memory in USS:", memUSS)
-            memRSS = ap.getMemoryRSS()
-            print("Total Memory in RSS", memRSS)
-            run = ap.getRuntime()
-            print("Total ExecutionTime in seconds:", run)
         print("Error! The number of input parameters do not match the total number of parameters provided")
+
