@@ -1,7 +1,8 @@
-from PAMI.highUtilitySpatialPattern.basic.abstract import *
-from functools import cmp_to_key
+from PAMI.highUtilitySpatialPattern.basic import abstract as _ab
+from functools import cmp_to_key as _cmpToKey
 
-class Transaction:
+
+class _Transaction:
     """
         A class to store Transaction of a database
 
@@ -10,12 +11,12 @@ class Transaction:
         items: list
             A list of items in transaction 
         utilities: list
-            A list of utilites of items in transaction
+            A list of utilities of items in transaction
         transactionUtility: int
             represent total sum of all utilities in the database
         pmus: list
             represent the pmu (probable maximum utility) of each element in the transaction
-        prefixutility:
+        prefixUtility:
             prefix Utility values of item
         offset:
             an offset pointer, used by projected transactions
@@ -55,7 +56,7 @@ class Transaction:
             :param offsetE: an offset over the original transaction for projecting the transaction
             :type offsetE: int
         """
-        new_transaction = Transaction(self.items, self.utilities, self.transactionUtility)
+        new_transaction = _Transaction(self.items, self.utilities, self.transactionUtility)
         utilityE = self.utilities[offsetE]
         new_transaction.prefixUtility = self.prefixUtility + utilityE
         new_transaction.transactionUtility = self.transactionUtility - utilityE
@@ -92,7 +93,7 @@ class Transaction:
     def removeUnpromisingItems(self, oldNamesToNewNames):
         """
             A method to remove items with low Utility than minUtil
-            :param oldNamesToNewNames: A map represent old namses to new names
+            :param oldNamesToNewNames: A map represent old names to new names
             :type oldNamesToNewNames: map
         """
         tempItems = []
@@ -123,7 +124,7 @@ class Transaction:
             self.utilities[j + 1] = utilityJ
 
 
-class Dataset:
+class _Dataset:
     """
         A class represent the list of transactions in this dataset
 
@@ -148,10 +149,11 @@ class Dataset:
     maxItem = 0
     
     def __init__(self, datasetpath, sep):
-        self.strToint = {}
-        self.intTostr = {}
+        self.strToInt = {}
+        self.intToStr = {}
         self.cnt = 1
         self.sep = sep
+        self.transactions = []
         with open(datasetpath, 'r') as f:
             lines = f.readlines()
             for line in lines:
@@ -178,17 +180,17 @@ class Dataset:
         utilities = []
         pmus = []
         for idx, item in enumerate(itemsString):
-            if (self.strToint).get(item) is None:
-                self.strToint[item] = self.cnt
-                self.intTostr[self.cnt] = item
+            if (self.strToInt).get(item) is None:
+                self.strToInt[item] = self.cnt
+                self.intToStr[self.cnt] = item
                 self.cnt += 1
-            item_int = self.strToint.get(item)
+            item_int = self.strToInt.get(item)
             if item_int > self.maxItem:
                 self.maxItem = item_int
             items.append(item_int)
             utilities.append(int(utilityString[idx]))
             pmus.append(int(pmuString[idx]))
-        return Transaction(items, utilities, transactionUtility, pmus)
+        return _Transaction(items, utilities, transactionUtility, pmus)
 
     def getMaxItem(self):
         """
@@ -203,7 +205,7 @@ class Dataset:
         return self.transactions
 
 
-class SHUIM(utilityPatterns):
+class SHUIM(_ab._utilityPatterns):
     """
       Spatial High Utility itemSet Mining (SHUIM) aims to discover all itemSets in a spatioTemporal database
        that satisfy the user-specified minimum utility and maximum distance constraints
@@ -255,7 +257,7 @@ class SHUIM(utilityPatterns):
                 Mining process will start from here
         getPatterns()
                 Complete set of patterns will be retrieved with this function
-        savePatterns(oFile)
+        save(oFile)
                 Complete set of frequent patterns will be loaded in to a output file
         getPatternsAsDataFrame()
                 Complete set of frequent patterns will be loaded in to a dataframe
@@ -273,7 +275,7 @@ class SHUIM(utilityPatterns):
                A method to  calculate the sub-tree utility and local utility of all items that can extend itemSet P and e
         output(tempPosition, utility)
                A method ave a high-utility itemSet to file or memory depending on what the user chose
-        is_equal(transaction1, transaction2)
+        _isEqual(transaction1, transaction2)
                A method to Check if two transaction are identical
         intersection(lst1, lst2)
                A method that return the intersection of 2 list
@@ -305,7 +307,7 @@ class SHUIM(utilityPatterns):
 
         print("Total number of Spatial high utility Patterns:", len(frequentPatterns))
 
-        obj.savePatterns("output")
+        obj.save("output")
 
         memUSS = obj.getMemoryUSS()
 
@@ -323,91 +325,93 @@ class SHUIM(utilityPatterns):
     -------
             The complete program was written by Pradeep Pallikila under the supervision of Professor Rage Uday Kiran.
     """
-    highUtilityItemSets = []
-    candidateCount = 0
-    utilityBinArrayLU = {}
-    utilityBinArraySU = {}
-    oldNamesToNewNames = {}
-    newNamesToOldNames = {}
-    strToint = {}
-    intTostr = {}
-    Neighbours = {}
-    temp = [0] * 5000
-    maxMemory = 0
-    startTime = float()
-    endTime = float()
-    minSup = str()
-    maxPer = float()
-    finalPatterns = {}
-    iFile = " "
-    oFile = " "
-    nFile = " "
-    sep = "\t"
-    minUtil = 0
-    memoryUSS = float()
-    memoryRSS = float()
+    _highUtilityItemSets = []
+    _candidateCount = 0
+    _utilityBinArrayLU = {}
+    _utilityBinArraySU = {}
+    _oldNamesToNewNames = {}
+    _newNamesToOldNames = {}
+    _strToInt = {}
+    _intToStr = {}
+    _Neighbours = {}
+    _temp = [0] * 5000
+    _maxMemory = 0
+    _startTime = float()
+    _endTime = float()
+    _minSup = str()
+    _maxPer = float()
+    _finalPatterns = {}
+    _iFile = " "
+    _oFile = " "
+    _nFile = " "
+    _sep = "\t"
+    _minUtil = 0
+    _memoryUSS = float()
+    _memoryRSS = float()
     
     def __init__(self, iFile, nFile, minUtil, sep="\t"):
         super().__init__(iFile, nFile, minUtil, sep)
 
     def startMine(self):
-        self.startTime = time.time()
-        self.patternCount = 0
-        self.finalPatterns = {}
-        self.dataset = Dataset(self.iFile, self.sep)
-        with open(self.nFile, 'r') as o:
+        self._startTime = _ab._time.time()
+        self._patternCount = 0
+        self._finalPatterns = {}
+        self._dataset = _Dataset(self._iFile, self._sep)
+        with open(self._nFile, 'r') as o:
             lines = o.readlines()
             for line in lines:
                 line = line.split("\n")[0]
-                line_split = line.split(self.sep)
-                item = self.dataset.strToint.get(line_split[0])
+                line_split = line.split(self._sep)
+                line_split = [i.strip() for i in line_split]
+                item = self._dataset.strToInt.get(line_split[0])
                 lst = []
                 for i in range(1, len(line_split)):
-                    lst.append(self.dataset.strToint.get(line_split[i]))
-                self.Neighbours[item] = lst
+                    lst.append(self._dataset.strToInt.get(line_split[i]))
+                self._Neighbours[item] = lst
         o.close()
-        InitialMemory = psutil.virtual_memory()[3]
-        self.useUtilityBinArrayToCalculateLocalUtilityFirstTime(self.dataset)
+        #print(len(self._Neighbours))
+        InitialMemory = _ab._psutil.virtual_memory()[3]
+        self._useUtilityBinArrayToCalculateLocalUtilityFirstTime(self._dataset)
         itemsToKeep = []
-        for key in self.utilityBinArrayLU.keys():
-            if self.utilityBinArrayLU[key] >= self.minUtil:
+        for key in self._utilityBinArrayLU.keys():
+            if self._utilityBinArrayLU[key] >= self._minUtil:
                 itemsToKeep.append(key)
-        itemsToKeep = sorted(itemsToKeep, key=lambda x: self.utilityBinArrayLU[x])
+        itemsToKeep = sorted(itemsToKeep, key=lambda x: self._utilityBinArrayLU[x])
         currentName = 1
         for idx, item in enumerate(itemsToKeep):
-            self.oldNamesToNewNames[item] = currentName
-            self.newNamesToOldNames[currentName] = item
+            self._oldNamesToNewNames[item] = currentName
+            self._newNamesToOldNames[currentName] = item
             itemsToKeep[idx] = currentName
             currentName += 1
-        for transaction in self.dataset.getTransactions():
-            transaction.removeUnpromisingItems(self.oldNamesToNewNames)
-        self.sortDatabase(self.dataset.getTransactions())
+        for transaction in self._dataset.getTransactions():
+            transaction.removeUnpromisingItems(self._oldNamesToNewNames)
+        self._sortDatabase(self._dataset.getTransactions())
         emptyTransactionCount = 0
-        for transaction in self.dataset.getTransactions():
+        for transaction in self._dataset.getTransactions():
             if len(transaction.getItems()) == 0:
                 emptyTransactionCount += 1
-        self.dataset.transactions = self.dataset.transactions[emptyTransactionCount:]
-        self.useUtilityBinArrayToCalculateSubtreeUtilityFirstTime(self.dataset)
+        self._dataset.transactions = self._dataset.transactions[emptyTransactionCount:]
+        self._useUtilityBinArrayToCalculateSubtreeUtilityFirstTime(self._dataset)
         itemsToExplore = []
         for item in itemsToKeep:
-            if self.utilityBinArraySU[item] >= self.minUtil:
+            if self._utilityBinArraySU[item] >= self._minUtil:
                 itemsToExplore.append(item)
         commonitems = []
-        for i in range(self.dataset.maxItem):
+        for i in range(self._dataset.maxItem):
             commonitems.append(i)
-        self.backtrackingEFIM(self.dataset.getTransactions(), itemsToKeep, itemsToExplore, 0)
-        finalMemory = psutil.virtual_memory()[3]
+        self._backtrackingEFIM(self._dataset.getTransactions(), itemsToKeep, itemsToExplore, 0)
+        finalMemory = _ab._psutil.virtual_memory()[3]
         memory = (finalMemory - InitialMemory) / 10000
-        if memory > self.maxMemory:
-            self.maxMemory = memory
-        self.endTime = time.time()
-        process = psutil.Process(os.getpid())
-        self.memoryUSS = float()
-        self.memoryRSS = float()
-        self.memoryUSS = process.memory_full_info().uss
-        self.memoryRSS = process.memory_info().rss
+        if memory > self._maxMemory:
+            self._maxMemory = memory
+        self._endTime = _ab._time.time()
+        process = _ab._psutil.Process(_ab._os.getpid())
+        self._memoryUSS = float()
+        self._memoryRSS = float()
+        self._memoryUSS = process.memory_full_info().uss
+        self._memoryRSS = process.memory_info().rss
 
-    def backtrackingEFIM(self, transactionsOfP, itemsToKeep, itemsToExplore, prefixLength):
+    def _backtrackingEFIM(self, transactionsOfP, itemsToKeep, itemsToExplore, prefixLength):
         """
             A method to mine the SHUIs Recursively
 
@@ -422,9 +426,9 @@ class SHUIM(utilityPatterns):
             :param prefixLength: current prefixLength
             :type prefixLength: int
         """
-        self.candidateCount += len(itemsToExplore)
+        self._candidateCount += len(itemsToExplore)
         for idx, e in enumerate(itemsToExplore):
-            initialMemory = psutil.virtual_memory()[3]
+            initialMemory = _ab._psutil.virtual_memory()[3]
             transactionsPe = []
             utilityPe = 0
             previousTransaction = transactionsOfP[0]
@@ -440,7 +444,7 @@ class SHUIM(utilityPatterns):
                         utilityPe += projectedTransaction.prefixUtility
                         if previousTransaction == transactionsOfP[0]:
                             previousTransaction = projectedTransaction
-                        elif self.is_equal(projectedTransaction, previousTransaction):
+                        elif self._isEqual(projectedTransaction, previousTransaction):
                             if consecutiveMergeCount == 0:
                                 items = previousTransaction.items[previousTransaction.offset:]
                                 utilities = previousTransaction.utilities[previousTransaction.offset:]
@@ -453,7 +457,7 @@ class SHUIM(utilityPatterns):
                                     positionProjection += 1
                                 previousTransaction.prefixUtility += projectedTransaction.prefixUtility
                                 sumUtilities = previousTransaction.prefixUtility
-                                previousTransaction = Transaction(items, utilities, previousTransaction.transactionUtility + projectedTransaction.transactionUtility)
+                                previousTransaction = _Transaction(items, utilities, previousTransaction.transactionUtility + projectedTransaction.transactionUtility)
                                 previousTransaction.prefixUtility = sumUtilities
                             else:
                                 positionPrevious = 0
@@ -474,30 +478,29 @@ class SHUIM(utilityPatterns):
                     transaction.offset = positionE
             if previousTransaction != transactionsOfP[0]:
                 transactionsPe.append(previousTransaction)
-            self.temp[prefixLength] = self.newNamesToOldNames[e]
-            if utilityPe >= self.minUtil:
-                self.output(prefixLength, utilityPe)
-            neighbourhoodList = self.calculateNeighbourIntersection(prefixLength)
-            #print(neighbourhoodList)
-            self.useUtilityBinArraysToCalculateUpperBounds(transactionsPe, idx, itemsToKeep, neighbourhoodList)
+            self._temp[prefixLength] = self._newNamesToOldNames[e]
+            if utilityPe >= self._minUtil:
+                self._output(prefixLength, utilityPe)
+            neighbourhoodList = self._calculateNeighbourIntersection(prefixLength)
+            self._useUtilityBinArraysToCalculateUpperBounds(transactionsPe, idx, itemsToKeep, neighbourhoodList)
             newItemsToKeep = []
             newItemsToExplore = []
             for l in range(idx + 1, len(itemsToKeep)):
                 itemK = itemsToKeep[l]
-                if self.utilityBinArraySU[itemK] >= self.minUtil:
+                if self._utilityBinArraySU[itemK] >= self._minUtil:
                     if itemK in neighbourhoodList:
                         newItemsToExplore.append(itemK)
                         newItemsToKeep.append(itemK)
-                elif self.utilityBinArrayLU[itemK] >= self.minUtil:
+                elif self._utilityBinArrayLU[itemK] >= self._minUtil:
                     if itemK in neighbourhoodList:
                         newItemsToKeep.append(itemK)
-            self.backtrackingEFIM(transactionsPe, newItemsToKeep, newItemsToExplore, prefixLength + 1)
-            finalMemory = psutil.virtual_memory()[3]
+            self._backtrackingEFIM(transactionsPe, newItemsToKeep, newItemsToExplore, prefixLength + 1)
+            finalMemory = _ab._psutil.virtual_memory()[3]
             memory = (finalMemory - initialMemory) / 10000
-            if self.maxMemory < memory:
-                self.maxMemory = memory
+            if self._maxMemory < memory:
+                self._maxMemory = memory
 
-    def useUtilityBinArraysToCalculateUpperBounds(self, transactionsPe, j, itemsToKeep, neighbourhoodList):
+    def _useUtilityBinArraysToCalculateUpperBounds(self, transactionsPe, j, itemsToKeep, neighbourhoodList):
         """
             A method to  calculate the sub-tree utility and local utility of all items that can extend itemSet P U {e}
 
@@ -513,8 +516,8 @@ class SHUIM(utilityPatterns):
         """
         for i in range(j + 1, len(itemsToKeep)):
             item = itemsToKeep[i]
-            self.utilityBinArrayLU[item] = 0
-            self.utilityBinArraySU[item] = 0
+            self._utilityBinArrayLU[item] = 0
+            self._utilityBinArraySU[item] = 0
         for transaction in transactionsPe:
             length = len(transaction.getItems())
             i = length - 1
@@ -522,19 +525,19 @@ class SHUIM(utilityPatterns):
                 item = transaction.getItems()[i]
                 if item in itemsToKeep:
                     remainingUtility = 0
-                    if self.newNamesToOldNames[item] in self.Neighbours:
-                        item_neighbours = self.Neighbours[self.newNamesToOldNames[item]]
+                    if self._newNamesToOldNames[item] in self._Neighbours:
+                        item_neighbours = self._Neighbours[self._newNamesToOldNames[item]]
                         for k in range(i, length):
                             transaction_item = transaction.getItems()[k]
-                            if self.newNamesToOldNames[transaction_item] in item_neighbours and transaction_item in neighbourhoodList:
+                            if self._newNamesToOldNames[transaction_item] in item_neighbours and transaction_item in neighbourhoodList:
                                 remainingUtility += transaction.getUtilities()[k]
 
                     remainingUtility += transaction.getUtilities()[i]
-                    self.utilityBinArraySU[item] += remainingUtility + transaction.prefixUtility
-                    self.utilityBinArrayLU[item] += transaction.transactionUtility + transaction.prefixUtility
+                    self._utilityBinArraySU[item] += remainingUtility + transaction.prefixUtility
+                    self._utilityBinArrayLU[item] += transaction.transactionUtility + transaction.prefixUtility
                 i -= 1
 
-    def calculateNeighbourIntersection(self, prefixLength):
+    def _calculateNeighbourIntersection(self, prefixLength):
         """
             A method to find common Neighbours
             Attributes:
@@ -543,18 +546,18 @@ class SHUIM(utilityPatterns):
                 :type prefixLength:int
 
         """
-        intersectionList = self.Neighbours.get(self.temp[0])
+        intersectionList = self._Neighbours.get(self._temp[0])
         for i in range(1, prefixLength+1):
-            intersectionList = self.intersection(self.Neighbours[self.temp[i]], intersectionList)
+            intersectionList = self._intersection(self._Neighbours[self._temp[i]], intersectionList)
         finalIntersectionList = []
         if intersectionList is None:
             return finalIntersectionList
         for item in intersectionList:
-            if item in self.oldNamesToNewNames:
-                finalIntersectionList.append(self.oldNamesToNewNames[item])
+            if item in self._oldNamesToNewNames:
+                finalIntersectionList.append(self._oldNamesToNewNames[item])
         return finalIntersectionList
     
-    def output(self, tempPosition, utility):
+    def _output(self, tempPosition, utility):
         """
          A method save all high-utility itemSet to file or memory depending on what the user chose
 
@@ -565,15 +568,15 @@ class SHUIM(utilityPatterns):
          :param utility: total utility of itemSet
          :type utility: int
         """
-        self.patternCount += 1
-        s1 = ""
+        self._patternCount += 1
+        s1 = str()
         for i in range(0, tempPosition+1):
-            s1 += self.dataset.intTostr.get((self.temp[i]))
+            s1 += self._dataset.intToStr.get((self._temp[i]))
             if i != tempPosition:
-                s1 += " "
-        self.finalPatterns[s1] = str(utility)
+                s1 += "\t"
+        self._finalPatterns[s1] = str(utility)
 
-    def is_equal(self, transaction1, transaction2):
+    def _isEqual(self, transaction1, transaction2):
         """
          A method to Check if two transaction are identical
 
@@ -600,7 +603,7 @@ class SHUIM(utilityPatterns):
             position2 += 1
         return True
     
-    def intersection(self, lst1, lst2):
+    def _intersection(self, lst1, lst2):
         """
             A method that return the intersection of 2 list
             :param  lst1: items neighbour to item1
@@ -614,7 +617,7 @@ class SHUIM(utilityPatterns):
         lst3 = [value for value in lst1 if value in temp]
         return lst3
 
-    def useUtilityBinArrayToCalculateSubtreeUtilityFirstTime(self, dataset):
+    def _useUtilityBinArrayToCalculateSubtreeUtilityFirstTime(self, dataset):
         """
         Scan the initial database to calculate the subtree utility of each items using a utility-bin array
 
@@ -627,20 +630,20 @@ class SHUIM(utilityPatterns):
             items = transaction.getItems()
             utilities = transaction.getUtilities()
             for idx, item in enumerate(items):
-                if item not in self.utilityBinArraySU:
-                    self.utilityBinArraySU[item] = 0
-                if self.newNamesToOldNames[item] not in self.Neighbours:
-                    self.utilityBinArraySU[item] += utilities[idx]
+                if item not in self._utilityBinArraySU:
+                    self._utilityBinArraySU[item] = 0
+                if self._newNamesToOldNames[item] not in self._Neighbours:
+                    self._utilityBinArraySU[item] += utilities[idx]
                     continue
                 i = idx + 1
                 sumSu = utilities[idx]
                 while i < len(items):
-                    if self.newNamesToOldNames[items[i]] in self.Neighbours[self.newNamesToOldNames[item]]:
+                    if self._newNamesToOldNames[items[i]] in self._Neighbours[self._newNamesToOldNames[item]]:
                         sumSu += utilities[i]
                     i += 1
-                self.utilityBinArraySU[item] += sumSu
+                self._utilityBinArraySU[item] += sumSu
 
-    def sortDatabase(self, transactions):
+    def _sortDatabase(self, transactions):
         """
             A Method to sort transaction in the order of PMU
 
@@ -651,10 +654,10 @@ class SHUIM(utilityPatterns):
             :return: sorted transaction
             :rtype: Transaction
         """
-        cmp_items = cmp_to_key(self.sort_transaction)
+        cmp_items = _cmpToKey(self._sortTransaction)
         transactions.sort(key=cmp_items)
 
-    def sort_transaction(self, trans1, trans2):
+    def _sortTransaction(self, trans1, trans2):
         """
             A Method to sort transaction in the order of PMU
 
@@ -696,7 +699,7 @@ class SHUIM(utilityPatterns):
                 pos2 -= 1
             return 0
 
-    def useUtilityBinArrayToCalculateLocalUtilityFirstTime(self, dataset):
+    def _useUtilityBinArrayToCalculateLocalUtilityFirstTime(self, dataset):
         """
             A method to scan the database using utility bin array to calculate the pmus
             Attributes:
@@ -707,10 +710,10 @@ class SHUIM(utilityPatterns):
         """
         for transaction in dataset.getTransactions():
             for idx, item in enumerate(transaction.getItems()):
-                if item in self.utilityBinArrayLU:
-                    self.utilityBinArrayLU[item] += transaction.getPmus()[idx]
+                if item in self._utilityBinArrayLU:
+                    self._utilityBinArrayLU[item] += transaction.getPmus()[idx]
                 else:
-                    self.utilityBinArrayLU[item] = transaction.getPmus()[idx]
+                    self._utilityBinArrayLU[item] = transaction.getPmus()[idx]
 
     def getPatternsAsDataFrame(self):
         """Storing final patterns in a dataframe
@@ -720,9 +723,9 @@ class SHUIM(utilityPatterns):
         """
         dataFrame = {}
         data = []
-        for a, b in self.finalPatterns.items():
-            data.append([a, b])
-            dataFrame = pd.DataFrame(data, columns=['Patterns', 'Utility'])
+        for a, b in self._finalPatterns.items():
+            data.append([a.replace('\t', ' '), b])
+            dataFrame = _ab._pd.DataFrame(data, columns=['Patterns', 'Utility'])
 
         return dataFrame
     
@@ -732,18 +735,18 @@ class SHUIM(utilityPatterns):
         :return: returning patterns
         :rtype: dict
         """
-        return self.finalPatterns
+        return self._finalPatterns
 
-    def savePatterns(self, outFile):
+    def save(self, outFile):
         """Complete set of patterns will be loaded in to a output file
 
         :param outFile: name of the output file
         :type outFile: file
         """
-        self.oFile = outFile
-        writer = open(self.oFile, 'w+')
-        for x, y in self.finalPatterns.items():
-            patternsAndSupport = str(x) + " : " + str(y)
+        self._oFile = outFile
+        writer = open(self._oFile, 'w+')
+        for x, y in self._finalPatterns.items():
+            patternsAndSupport = x.strip() + ":" + str(y)
             writer.write("%s \n" % patternsAndSupport)
 
     def getMemoryUSS(self):
@@ -753,7 +756,7 @@ class SHUIM(utilityPatterns):
         :rtype: float
         """
 
-        return self.memoryUSS
+        return self._memoryUSS
 
     def getMemoryRSS(self):
         """Total amount of RSS memory consumed by the mining process will be retrieved from this function
@@ -761,7 +764,7 @@ class SHUIM(utilityPatterns):
         :return: returning RSS memory consumed by the mining process
         :rtype: float
        """
-        return self.memoryRSS
+        return self._memoryRSS
 
     def getRuntime(self):
         """Calculating the total amount of runtime taken by the mining process
@@ -770,25 +773,35 @@ class SHUIM(utilityPatterns):
         :return: returning total amount of runtime taken by the mining process
         :rtype: float
        """
-        return self.endTime-self.startTime
+        return self._endTime-self._startTime
+
+    def printResults(self):
+        print("Total number of Spatial High Utility Patterns:", len(self.getPatterns()))
+        print("Total Memory in USS:", self.getMemoryUSS())
+        print("Total Memory in RSS", self.getMemoryRSS())
+        print("Total ExecutionTime in seconds:", self.getRuntime())
 
 
 if __name__ == '__main__':
-    ap = str()
-    if len(sys.argv) == 5 or len(sys.argv) == 6:
-        if len(sys.argv) == 6:
-            ap = SHUIM(sys.argv[1], sys.argv[3], int(sys.argv[4]), sys.argv[5])
-        if len(sys.argv) == 5:
-            ap = SHUIM(sys.argv[1], sys.argv[3], int(sys.argv[4]))
-        ap.startMine()
-        patterns = ap.getPatterns()
-        print("Total number of Spatial High Utility Patterns:", len(patterns))
-        ap.savePatterns(sys.argv[2])
-        memUSS = ap.getMemoryUSS()
-        print("Total Memory in USS:", memUSS)
-        memRSS = ap.getMemoryRSS()
-        print("Total Memory in RSS", memRSS)
-        run = ap.getRuntime()
-        print("Total ExecutionTime in seconds:", run)
+    _ap = str()
+    if len(_ab._sys.argv) == 5 or len(_ab._sys.argv) == 6:
+        if len(_ab._sys.argv) == 6:
+            _ap = SHUIM(_ab._sys.argv[1], _ab._sys.argv[3], int(_ab._sys.argv[4]), _ab._sys.argv[5])
+        if len(_ab._sys.argv) == 5:
+            _ap = SHUIM(_ab._sys.argv[1], _ab._sys.argv[3], int(_ab._sys.argv[4]))
+        _ap.startMine()
+        print("Total number of Spatial High Utility Patterns:", len( _ap.getPatterns()))
+        _ap.save(_ab._sys.argv[2])
+        print("Total Memory in USS:", _ap.getMemoryUSS())
+        print("Total Memory in RSS", _ap.getMemoryRSS())
+        print("Total ExecutionTime in seconds:", _ap.getRuntime())
     else:
+        for i in [2000, 4000, 6000, 8000, 10000]:
+            _ap = SHUIM('/Users/Likhitha/Downloads/main_9.txt', '/Users/Likhitha/Downloads/mushroom_neighbourhoodFile_9.txt', i, ' ')
+            _ap.startMine()
+            print("Total number of Spatial High Utility Patterns:", len(_ap.getPatterns()))
+            #_ap.save(_ab._sys.argv[2])
+            print("Total Memory in USS:", _ap.getMemoryUSS())
+            print("Total Memory in RSS", _ap.getMemoryRSS())
+            print("Total ExecutionTime in seconds:", _ap.getRuntime())
         print("Error! The number of input parameters do not match the total number of parameters provided")
