@@ -277,7 +277,7 @@ class generatePFListver2:
         for item in self.PFList:
             if last - self.PFList[item][2] <= self.maxPer:
                 self.PFList[item][1] += 1
-            if self.PFList[item][1] / (self.minSup + 1) < self.minPR or self.PFList[item][1] < self.minSup:
+            if self.PFList[item][1] / (self.minSup + 1) < self.minPR or self.PFList[item][0] < self.minSup:
                 del self.tsList[item]
         #self.PFList = {tuple([k]): v for k, v in sorted(self.PFList.items(), key=lambda x:x[1], reverse=True)}
         tidList = {tuple([k]): v for k, v in sorted(self.tsList.items(), key=lambda x:len(x[1]), reverse=True)}
@@ -445,7 +445,11 @@ class PFgrowth:
 class GPFgrowth(partialPeriodicPatterns):
     """
     GPFgrowth is algorithm to mine the partial periodic frequent pattern in temporal database.
-
+    
+    Reference:
+    ---------
+    R. Uday Kiran, J.N. Venkatesh, Masashi Toyoda, Masaru Kitsuregawa, P. Krishna Reddy, Discovering partial periodic-frequent patterns in a transactional database,
+    Journal of Systems and Software, Volume 125, 2017, Pages 170-182, ISSN 0164-1212, https://doi.org/10.1016/j.jss.2016.11.035.
     ...
     Attributes:
     ----------
@@ -503,7 +507,7 @@ class GPFgrowth(partialPeriodicPatterns):
 
         print("Total number of partial periodic Patterns:", len(partialPeriodicFrequentPatterns))
 
-        obj.savePatterns(oFile)
+        obj.save(oFile)
 
         Df = obj.getPatternInDf()
 
@@ -554,12 +558,13 @@ class GPFgrowth(partialPeriodicPatterns):
         return value
 
     def __readDatabase(self):
+        self.__Database = []
         if isinstance(self.__inputFile, pd.DataFrame):
             if self.__inputFile.empty:
                 print("its empty..")
             i = self.__inputFile.columns.values.tolist()
             if 'Transactions' in i:
-                self.Database = self.__inputFile['Transactions'].tolist()
+                self.__Database = self.__inputFile['Transactions'].tolist()
             if 'Patterns' in i:
                 self.__Database = self.__inputFile['Patterns'].tolist()
         if isinstance(self.__inputFile, str):
@@ -587,6 +592,7 @@ class GPFgrowth(partialPeriodicPatterns):
     def startMine(self):
         self.__inputFile = self._partialPeriodicPatterns__iFile
         self._partialPeriodicPatterns__startTime = time.time()
+        self._partialPeriodicPatterns__finalPatterns = {}
         self.__readDatabase()
         self._partialPeriodicPatterns__minSup = self.__convert(self._partialPeriodicPatterns__minSup)
         self._partialPeriodicPatterns__maxPer = self.__convert(self._partialPeriodicPatterns__maxPer)
@@ -639,11 +645,18 @@ class GPFgrowth(partialPeriodicPatterns):
         dataframe = {}
         data = []
         for a, b in self._partialPeriodicPatterns__finalPatterns.items():
-            data.append([a, b[0], b[1]])
-            dataframe = pd.DataFrame(data, columns=['Patterns', 'Support', 'Periodicity'])
+            if len(a) == 1:
+                pattern = f'{a[0][0]}'
+            else:
+                pattern = f'{a[0][0]}'
+                for item in a[1:]:
+                    pattern = pattern + f' {item[0]}'
+            #print(pattern)
+            data.append([pattern, b[0], b[1]])
+            dataframe = pd.DataFrame(data, columns=['Patterns', 'Support', 'PeriodicRatio'])
         return dataframe
 
-    def savePatterns(self, outFile):
+    def save(self, outFile):
         """Complete set of frequent patterns will be loaded in to a output file
         :param outFile: name of the output file
         :type outFile: file
@@ -651,8 +664,13 @@ class GPFgrowth(partialPeriodicPatterns):
         self.oFile = outFile
         writer = open(self.oFile, 'w+')
         for x, y in self._partialPeriodicPatterns__finalPatterns.items():
-            s1 = str(x) + ":" + str(y)
-            writer.write("%s \n" % s1)
+            if len(x) == 1:
+                writer.write(f'{x[0][0]}:{y[0]}:{y[1]}\n')
+            else:
+                writer.write(f'{x[0][0]}')
+                for item in x[1:]:
+                    writer.write(f'\t{item[0]}')
+                writer.write(f':{y[0]}:{y[1]}\n')\
 
     def getPatterns(self):
         """ Function to send the set of frequent patterns after completion of the mining process
@@ -661,6 +679,12 @@ class GPFgrowth(partialPeriodicPatterns):
         """
         return self._partialPeriodicPatterns__finalPatterns
 
+    def printResults(self):
+        print("Total number of Partial Periodic Frequent Patterns:", len(self.getPatterns()))
+        print("Total Memory in USS:", self.getMemoryUSS())
+        print("Total Memory in RSS", self.getMemoryRSS())
+        print("Total ExecutionTime in ms:", self.getRuntime())
+
 if __name__ == '__main__':
     ap = str()
     if len(sys.argv) == 6 or len(sys.argv) == 7:
@@ -669,26 +693,18 @@ if __name__ == '__main__':
         if len(sys.argv) == 6:
             ap = GPFgrowth(sys.argv[1], sys.argv[3], sys.argv[4], sys.argv[5])
         ap.startMine()
-        Patterns = ap.getPatterns()
-        print("Total number of Frequent Patterns:", len(Patterns))
-        ap.savePatterns(sys.argv[2])
-        memUSS = ap.getMemoryUSS()
-        print("Total Memory in USS:", memUSS)
-        memRSS = ap.getMemoryRSS()
-        print("Total Memory in RSS", memRSS)
-        run = ap.getRuntime()
-        print("Total ExecutionTime in ms:", run)
+        print("Total number of Frequent Patterns:", len(ap.getPatterns()))
+        ap.save(sys.argv[2])
+        print("Total Memory in USS:", ap.getMemoryUSS())
+        print("Total Memory in RSS", ap.getMemoryRSS())
+        print("Total ExecutionTime in ms:", ap.getRuntime())
     else:
-        ap = GPFgrowth('https://www.u-aizu.ac.jp/~udayrage/datasets/temporalDatabases/temporal_T10I4D100K.csv',
-                     500, 1000, 0.8)
-        ap.startMine()
-        Patterns = ap.getPatterns()
-        print("Total number of Frequent Patterns:", len(Patterns))
-        # ap.savePatterns('/home/apiiit-rkv/Downloads/fp_pami/output')
-        memUSS = ap.getMemoryUSS()
-        print("Total Memory in USS:", memUSS)
-        memRSS = ap.getMemoryRSS()
-        print("Total Memory in RSS", memRSS)
-        run = ap.getRuntime()
-        print("Total ExecutionTime in ms:", run)
+        for i in [1000, 2000, 3000, 4000, 5000]:
+            _ap = GPFgrowth('/Users/Likhitha/Downloads/temporal_T10I4D100K.csv', i, 500, 0.7, '\t')
+            _ap.startMine()
+            print("Total number of Maximal Partial Periodic Patterns:", len(_ap.getPatterns()))
+            _ap.save('/Users/Likhitha/Downloads/output.txt')
+            print("Total Memory in USS:", _ap.getMemoryUSS())
+            print("Total Memory in RSS", _ap.getMemoryRSS())
+            print("Total ExecutionTime in ms:", _ap.getRuntime())
         print("Error! The number of input parameters do not match the total number of parameters provided")
