@@ -54,7 +54,7 @@ class PPF_DFS(partialPeriodicPatterns):
             Mining process will start from here
         getPartialPeriodicPatterns()
             Complete set of patterns will be retrieved with this function
-        savePatterns(ouputFile)
+        save(ouputFile)
             Complete set of frequent patterns will be loaded in to a ouput file
         getPatternsAsDataFrame()
             Complete set of frequent patterns will be loaded in to a ouput file
@@ -86,7 +86,7 @@ class PPF_DFS(partialPeriodicPatterns):
 
         print("Total number of Frequent Patterns:", len(frequentPatterns))
 
-        obj.savePatterns(oFile)
+        obj.save(oFile)
 
         Df = obj.getPatternInDataFrame()
 
@@ -362,7 +362,6 @@ class PPF_DFS(partialPeriodicPatterns):
         self._partialPeriodicPatterns__startTime = time.time()
         self.__creatingItemSets()
         plist = self.__oneItems(self.__path)
-        #print(len(plist))
         self._partialPeriodicPatterns__finalPatterns = {}
         for i in range(len(plist)):
             itemx = plist[i]
@@ -375,14 +374,13 @@ class PPF_DFS(partialPeriodicPatterns):
                 tidsetj = self.__tidlist[itemj]
                 y1 = list(set(tidsetx) & set(tidsetj))
                 val = self._partialPeriodicPatterns__getPerSup(y1)
-                # if(len(y1)>=minsup and val/(len(y1)+1)>=minpr):
                 if len(y1) >= self._partialPeriodicPatterns__minSup and val / (self._partialPeriodicPatterns__minSup + 1) >= self._partialPeriodicPatterns__minPR:
                     itemsets.append(itemj)
                     tidsets.append(y1)
             self.__Generation(itemsetx, itemsets, tidsets)
             self.__save(None, itemsetx, tidsetx)
         self._partialPeriodicPatterns__endTime = time.time()
-        self.__runTime = (self._partialPeriodicPatterns__endTime - self._partialPeriodicPatterns__startTime)
+        self.__runTime = self._partialPeriodicPatterns__endTime - self._partialPeriodicPatterns__startTime
         process = psutil.Process(os.getpid())
         self._partialPeriodicPatterns__memoryUSS = float()
         self._partialPeriodicPatterns__memoryRSS = float()
@@ -424,11 +422,17 @@ class PPF_DFS(partialPeriodicPatterns):
         dataframe = {}
         data = []
         for a, b in self._partialPeriodicPatterns__finalPatterns.items():
-            data.append([a, b[0], b[1]])
+            if len(a) == 1:
+                pattern = f'{a[0]}'
+            else:
+                pattern = f'{a[0]}'
+                for item in a[1:]:
+                    pattern = pattern + f' {item}'
+            data.append([pattern, b[0], b[1]])
             dataframe = pd.DataFrame(data, columns=['Patterns', 'Support', 'Periodicity'])
         return dataframe
 
-    def savePatterns(self, outFile):
+    def save(self, outFile):
         """Complete set of frequent patterns will be loaded in to a output file
         :param outFile: name of the output file
         :type outFile: file
@@ -436,8 +440,15 @@ class PPF_DFS(partialPeriodicPatterns):
         self._partialPeriodicPatterns__oFile = outFile
         writer = open(self._partialPeriodicPatterns__oFile, 'w+')
         for x, y in self._partialPeriodicPatterns__finalPatterns.items():
-            s1 = str(x) + ":" + str(y)
-            writer.write("%s \n" % s1)
+            if len(x) == 1:
+                writer.write(f'{x[0]}:{y[0]}:{y[1]}\n')
+            else:
+                writer.write(f'{x[0]}')
+                for item in x[1:]:
+                    writer.write(f'\t{item}')
+                writer.write(f':{y[0]}:{y[1]}\n')
+            # s1 = str(x) + ":" + str(y)
+            # writer.write("%s \n" % s1)
 
     def getPatterns(self):
         """ Function to send the set of frequent patterns after completion of the mining process
@@ -446,6 +457,11 @@ class PPF_DFS(partialPeriodicPatterns):
         """
         return self._partialPeriodicPatterns__finalPatterns
 
+    def printResults(self):
+        print("Total number of Partial Periodic Frequent Patterns:", len(self.getPatterns()))
+        print("Total Memory in USS:", self.getMemoryUSS())
+        print("Total Memory in RSS", self.getMemoryRSS())
+        print("Total ExecutionTime in ms:", self.getRuntime())
 
 if __name__ == '__main__':
     ap = str()
@@ -455,28 +471,20 @@ if __name__ == '__main__':
         if len(sys.argv) == 6:
             ap = PPF_DFS(sys.argv[1], sys.argv[3], sys.argv[4], sys.argv[5])
         ap.startMine()
-        Patterns = ap.getPatterns()
-        print("Total number of Frequent Patterns:", len(Patterns))
-        ap.savePatterns(sys.argv[2])
-        memUSS = ap.getMemoryUSS()
-        print("Total Memory in USS:", memUSS)
-        memRSS = ap.getMemoryRSS()
-        print("Total Memory in RSS", memRSS)
-        run = ap.getRuntime()
-        print("Total ExecutionTime in ms:", run)
+        print("Total number of Frequent Patterns:", len(ap.getPatterns()))
+        ap.save(sys.argv[2])
+        print("Total Memory in USS:", ap.getMemoryUSS())
+        print("Total Memory in RSS", ap.getMemoryRSS())
+        print("Total ExecutionTime in ms:", ap.getRuntime())
     else:
-        ap = PPF_DFS('https://www.u-aizu.ac.jp/~udayrage/datasets/temporalDatabases/temporal_T10I4D100K.csv',
-                     500, 1000, 0.8)
-        ap.startMine()
-        Patterns = ap.getPatterns()
-        print("Total number of Frequent Patterns:", len(Patterns))
-        # ap.savePatterns('/home/apiiit-rkv/Downloads/fp_pami/output')
-        memUSS = ap.getMemoryUSS()
-        print("Total Memory in USS:", memUSS)
-        memRSS = ap.getMemoryRSS()
-        print("Total Memory in RSS", memRSS)
-        run = ap.getRuntime()
-        print("Total ExecutionTime in ms:", run)
+        for i in [1000, 2000, 3000, 4000, 5000]:
+            _ap = PPF_DFS('/Users/Likhitha/Downloads/temporal_T10I4D100K.csv', i, 500, 0.7, '\t')
+            _ap.startMine()
+            print("Total number of Maximal Partial Periodic Patterns:", len(_ap.getPatterns()))
+            _ap.save('/Users/Likhitha/Downloads/output.txt')
+            print("Total Memory in USS:", _ap.getMemoryUSS())
+            print("Total Memory in RSS", _ap.getMemoryRSS())
+            print("Total ExecutionTime in ms:", _ap.getRuntime())
         print("Error! The number of input parameters do not match the total number of parameters provided")
 
 
