@@ -294,7 +294,7 @@ class PPPGrowth(_abstract._partialPeriodicPatterns):
             Mining process will start from here
         getPatterns()
             Complete set of patterns will be retrieved with this function
-        savePatterns(oFile)
+        save(oFile)
             Complete set of frequent patterns will be loaded in to a output file
         getPatternsAsDataFrame()
             Complete set of frequent patterns will be loaded in to a dataframe
@@ -334,7 +334,7 @@ class PPPGrowth(_abstract._partialPeriodicPatterns):
 
         print("Total number of partial periodic Patterns:", len(partialPeriodicPatterns))
 
-        obj.savePatterns(oFile)
+        obj.save(oFile)
 
         Df = obj.getPatternInDf()
 
@@ -482,7 +482,7 @@ class PPPGrowth(_abstract._partialPeriodicPatterns):
         """
         temp = str()
         for i in itemset:
-            temp = temp + self._rankdup[i] + " "
+            temp = temp + self._rankdup[i] + "\t"
         return temp
 
     def _convert(self, value):
@@ -574,11 +574,11 @@ class PPPGrowth(_abstract._partialPeriodicPatterns):
         dataFrame = {}
         data = []
         for a, b in self._finalPatterns.items():
-            data.append([a, b])
+            data.append([a.replace('\t', ' '), b])
             dataFrame = _abstract._pd.DataFrame(data, columns=['Patterns', 'periodicSupport'])
         return dataFrame
 
-    def savePatterns(self, outFile):
+    def save(self, outFile):
         """Complete set of frequent patterns will be loaded in to a output file
 
         :param outFile: name of the output file
@@ -587,7 +587,7 @@ class PPPGrowth(_abstract._partialPeriodicPatterns):
         self._oFile = outFile
         writer = open(self._oFile, 'w+')
         for x, y in self._finalPatterns.items():
-            s1 = x + ":" + str(y)
+            s1 = x.strip() + ":" + str(y)
             writer.write("%s \n" % s1)
 
     def getPatterns(self):
@@ -598,36 +598,25 @@ class PPPGrowth(_abstract._partialPeriodicPatterns):
         """
         return self._finalPatterns
 
+    def printResults(self):
+        print("Total number of Partial Periodic Patterns:", len(self.getPatterns()))
+        print("Total Memory in USS:", self.getMemoryUSS())
+        print("Total Memory in RSS", self.getMemoryRSS())
+        print("Total ExecutionTime in ms:",  self.getRuntime())
+
 
 if __name__ == "__main__":
-    ap = str()
+    _ap = str()
     if len(_sys.argv) == 5 or len(_sys.argv) == 6:
         if len(_sys.argv) == 6:
-            ap = PPPGrowth(_sys.argv[1], _sys.argv[3], _sys.argv[4], _sys.argv[5])
+            _ap = PPPGrowth(_sys.argv[1], _sys.argv[3], _sys.argv[4], _sys.argv[5])
         if len(_sys.argv) == 5:
-            ap = PPPGrowth(_sys.argv[1], _sys.argv[3], _sys.argv[4])
-        ap.startMine()
-        Patterns = ap.getPatterns()
-        print("Total number of Partial Periodic Patterns:", len(Patterns))
-        ap.savePatterns(_sys.argv[2])
-        memUSS = ap.getMemoryUSS()
-        print("Total Memory in USS:", memUSS)
-        memRSS = ap.getMemoryRSS()
-        print("Total Memory in RSS", memRSS)
-        run = ap.getRuntime()
-        print("Total ExecutionTime in ms:", run)
+            _ap = PPPGrowth(_sys.argv[1], _sys.argv[3], _sys.argv[4])
+        _ap.startMine()
+        print("Total number of Partial Periodic Patterns:", len(_ap.getPatterns()))
+        _ap.save(_sys.argv[2])
+        print("Total Memory in USS:", _ap.getMemoryUSS())
+        print("Total Memory in RSS", _ap.getMemoryRSS())
+        print("Total ExecutionTime in ms:",  _ap.getRuntime())
     else:
-        l = [0.001, 0.002, 0.003, 0.004, 0.005]
-        for i in l:
-            ap = PPPGrowth('/Users/Likhitha/Downloads/Datasets/BMS1_itemset_mining.txt', i, 100, ' ')
-            ap.startMine()
-            Patterns = ap.getPatterns()
-            print("Total number of  Patterns:", len(Patterns))
-            ap.savePatterns('/Users/Likhitha/Downloads/output')
-            memUSS = ap.getMemoryUSS()
-            print("Total Memory in USS:", memUSS)
-            memRSS = ap.getMemoryRSS()
-            print("Total Memory in RSS", memRSS)
-            run = ap.getRuntime()
-            print("Total ExecutionTime in ms:", run)
         print("Error! The number of input parameters do not match the total number of parameters provided")
