@@ -18,6 +18,7 @@ import validators as _validators
 from urllib.request import urlopen as _urlopen
 from PAMI.partialPeriodicPattern.maximal import abstract as _abstract
 
+global maximalTree
 _periodicSupport = float()
 _period = float()
 _lno = int()
@@ -101,7 +102,7 @@ class _Tree(object):
         self.root = _Node(None, {})
         self.summaries = {}
         self.info = {}
-        self.maximalTree = _MPTree()
+        #self.maximalTree = _MPTree()
 
     def _addTransaction(self, transaction, tid):
         """
@@ -176,7 +177,7 @@ class _Tree(object):
             temp += i.timeStamps
         return temp
 
-    def _generatePatterns(self, prefix, _patterns):
+    def _generatePatterns(self, prefix, _patterns, maximalTree):
         """
             To generate the maximal periodic frequent patterns
 
@@ -196,13 +197,13 @@ class _Tree(object):
             for k in info:
                 tail.append(k)
             sub = head + tail
-            if self.maximalTree._checkerSub(sub) == 1:
+            if maximalTree._checkerSub(sub) == 1:
                 for pat in range(len(condPattern)):
                     conditionalTree._addTransaction(condPattern[pat], timeStamps[pat])
                 if len(condPattern) >= 1:
-                    conditionalTree._generatePatterns(pattern, _patterns)
+                    conditionalTree._generatePatterns(pattern, _patterns, maximalTree)
                 else:
-                    self.maximalTree._addTransaction(pattern)
+                    maximalTree._addTransaction(pattern)
                     _patterns[tuple(pattern)] = self.info[i]
             self._removeNode(i)
 
@@ -315,7 +316,7 @@ class _MPTree(object):
         return 1
 
 
-#_maximalTree = _MPTree()
+#maximalTree = _MPTree()
 
 
 def _getPeriodAndSupport(timeStamps):
@@ -430,7 +431,7 @@ class Max3PGrowth(_abstract._partialPeriodicPatterns):
                 Mining process will start from here
             getFrequentPatterns()
                 Complete set of patterns will be retrieved with this function
-            savePatterns(oFile)
+            save(oFile)
                 Complete set of periodic-frequent patterns will be loaded in to a output file
             getPatternsAsDataFrame()
                 Complete set of periodic-frequent patterns will be loaded in to a dataframe
@@ -476,7 +477,7 @@ class Max3PGrowth(_abstract._partialPeriodicPatterns):
 
             print("Total number of partial periodic Patterns:", len(partialPeriodicPatterns))
 
-            obj.savePatterns(oFile)
+            obj.save(oFile)
 
             Df = obj.getPatternInDf()
 
@@ -514,6 +515,7 @@ class Max3PGrowth(_abstract._partialPeriodicPatterns):
     _lno = 0
     _patterns = {}
     _pfList = {}
+    _maximalTree = str()
 
     def _creatingitemSets(self):
         """ Storing the complete Databases of the database/input file in a database variable
@@ -676,13 +678,14 @@ class Max3PGrowth(_abstract._partialPeriodicPatterns):
         info = {self._rank[k]: v for k, v in generatedItems.items()}
         Tree = self._buildTree(updatedDatabases, info)
         self._patterns = {}
-        Tree._generatePatterns([], self._patterns)
+        self._maximalTree = _MPTree()
+        Tree._generatePatterns([], self._patterns, self._maximalTree)
         self._finalPatterns = {}
         for x, y in self._patterns.items():
             st = str()
             x = self._convertItems(x)
             for k in x:
-                st = st + k + " "
+                st = st + k + "\t"
             self._finalPatterns[st] = y
         self._endTime = _abstract._time.time()
         process = _abstract._psutil.Process(_abstract._os.getpid())
@@ -730,11 +733,11 @@ class Max3PGrowth(_abstract._partialPeriodicPatterns):
         dataFrame = {}
         data = []
         for a, b in self._finalPatterns.items():
-            data.append([a, b])
+            data.append([a.replace('\t', ' '), b])
             dataFrame = _abstract._pd.DataFrame(data, columns=['Patterns', 'periodicSupport'])
         return dataFrame
 
-    def savePatterns(self, outFile):
+    def save(self, outFile):
         """Complete set of periodic-frequent patterns will be loaded in to a output file
 
         :param outFile: name of the output file
@@ -743,7 +746,7 @@ class Max3PGrowth(_abstract._partialPeriodicPatterns):
         self._oFile = outFile
         writer = open(self._oFile, 'w+')
         for x, y in self._finalPatterns.items():
-            s1 = x + ":" + str(y)
+            s1 = x.strip() + ":" + str(y)
             writer.write("%s \n" % s1)
 
     def getPatterns(self):
@@ -754,36 +757,33 @@ class Max3PGrowth(_abstract._partialPeriodicPatterns):
         """
         return self._finalPatterns
 
+    def printResults(self):
+        print("Total number of  Maximal Partial Periodic Patterns:", len(self.getPatterns()))
+        print("Total Memory in USS:", self.getMemoryUSS())
+        print("Total Memory in RSS", self.getMemoryRSS())
+        print("Total ExecutionTime in ms:",  self.getRuntime())
+
 
 if __name__ == "__main__":
-    ap = str()
+    _ap = str()
     if len(_sys.argv) == 5 or len(_sys.argv) == 6:
         if len(_sys.argv) == 6:
-            ap = Max3PGrowth(_sys.argv[1], _sys.argv[3], _sys.argv[4], _sys.argv[5])
+            _ap = Max3PGrowth(_sys.argv[1], _sys.argv[3], _sys.argv[4], _sys.argv[5])
         if len(_sys.argv) == 5:
-            ap = Max3PGrowth(_sys.argv[1], _sys.argv[3], _sys.argv[4])
-        ap.startMine()
-        Patterns = ap.getPatterns()
-        print("Total number of Maximal Partial Periodic Patterns:", len(Patterns))
-        ap.savePatterns(_sys.argv[2])
-        memUSS = ap.getMemoryUSS()
-        print("Total Memory in USS:", memUSS)
-        memRSS = ap.getMemoryRSS()
-        print("Total Memory in RSS", memRSS)
-        run = ap.getRuntime()
-        print("Total ExecutionTime in ms:", run)
+            _ap = Max3PGrowth(_sys.argv[1], _sys.argv[3], _sys.argv[4])
+        _ap.startMine()
+        print("Total number of Maximal Partial Periodic Patterns:", len(_ap.getPatterns()))
+        _ap.save(_sys.argv[2])
+        print("Total Memory in USS:", _ap.getMemoryUSS())
+        print("Total Memory in RSS", _ap.getMemoryRSS())
+        print("Total ExecutionTime in ms:", _ap.getRuntime())
     else:
-        l = [0.001, 0.002, 0.003, 0.004, 0.005]
-        for i in l:
-            ap = Max3PGrowth('/Users/Likhitha/Downloads/Datasets/BMS1_itemset_mining.txt', i, 100, ' ')
-            ap.startMine()
-            Patterns = ap.getPatterns()
-            print("Total number of  Patterns:", len(Patterns))
-            ap.savePatterns('/Users/Likhitha/Downloads/output')
-            memUSS = ap.getMemoryUSS()
-            print("Total Memory in USS:", memUSS)
-            memRSS = ap.getMemoryRSS()
-            print("Total Memory in RSS", memRSS)
-            run = ap.getRuntime()
-            print("Total ExecutionTime in ms:", run)
+        for i in [100, 200, 300, 400, 500]:
+            _ap = Max3PGrowth('/Users/Likhitha/Downloads/temporal_T10I4D100K.csv', i, 5000, '\t')
+            _ap.startMine()
+            print("Total number of Maximal Partial Periodic Patterns:", len(_ap.getPatterns()))
+            _ap.save('/Users/Likhitha/Downloads/output.txt')
+            print("Total Memory in USS:", _ap.getMemoryUSS())
+            print("Total Memory in RSS", _ap.getMemoryRSS())
+            print("Total ExecutionTime in ms:", _ap.getRuntime())
         print("Error! The number of input parameters do not match the total number of parameters provided")
