@@ -16,7 +16,7 @@
 
 from PAMI.periodicFrequentPattern.maximal import abstract as _ab
 
-
+#global maximalTree
 _minSup = float()
 _maxPer = float()
 _lno = int()
@@ -96,7 +96,7 @@ class _Tree(object):
         self.root = _Node(None, {})
         self.summaries = {}
         self.info = {}
-        self.maximalTree = _MPTree()
+        #self.maximalTree = _MPTree()
 
     def addTransaction(self, transaction, tid):
         """
@@ -170,7 +170,7 @@ class _Tree(object):
             temp += i.timeStamps
         return temp
 
-    def generatePatterns(self, prefix, patterns):
+    def generatePatterns(self, prefix, patterns, maximalTree):
         """
             To generate the maximal periodic frequent patterns
 
@@ -178,6 +178,7 @@ class _Tree(object):
 
             :return: maximal periodic frequent patterns
         """
+        #global maximalTree
         for i in sorted(self.summaries, key=lambda x: (self.info.get(x), -x)):
             pattern = prefix[:]
             pattern.append(i)
@@ -189,13 +190,13 @@ class _Tree(object):
             for k in info:
                 tail.append(k)
             sub = head + tail
-            if self.maximalTree.checkerSub(sub) == 1:
+            if maximalTree.checkerSub(sub) == 1:
                 for pat in range(len(condPattern)):
                     conditionalTree.addTransaction(condPattern[pat], timeStamps[pat])
                 if len(condPattern) >= 1:
-                    conditionalTree.generatePatterns(pattern, patterns)
+                    conditionalTree.generatePatterns(pattern, patterns, maximalTree)
                 else:
-                    self.maximalTree.addTransaction(pattern)
+                    maximalTree.addTransaction(pattern)
                     #s = convert(pattern)
                     patterns[tuple(pattern)] = self.info[i]
             self.removeNode(i)
@@ -304,7 +305,7 @@ class _MPTree(object):
         return 1
 
 
-#maximalTree = MPTree()
+#maximalTree = _MPTree()
 
 
 def _getPeriodAndSupport(timeStamps):
@@ -414,7 +415,7 @@ class MaxPFGrowth(_ab._periodicFrequentPatterns):
                 Mining process will start from here
             getPatterns()
                 Complete set of patterns will be retrieved with this function
-            savePatterns(oFile)
+            save(oFile)
                 Complete set of periodic-frequent patterns will be loaded in to a output file
             getPatternsAsDataFrame()
                 Complete set of periodic-frequent patterns will be loaded in to a dataframe
@@ -460,7 +461,7 @@ class MaxPFGrowth(_ab._periodicFrequentPatterns):
 
             print("Total number of Frequent Patterns:", len(Patterns))
 
-            obj.savePatterns("patterns")
+            obj.save("patterns")
 
             Df = obj.getPatternsAsDataFrame()
     
@@ -496,6 +497,7 @@ class MaxPFGrowth(_ab._periodicFrequentPatterns):
     _rankedUp = {}
     _lno = 0
     _patterns = {}
+    _maximalTree = str()
 
     def __init__(self, iFile, minSup, maxPer, sep='\t'):
         super().__init__(iFile, minSup, maxPer, sep)
@@ -654,7 +656,8 @@ class MaxPFGrowth(_ab._periodicFrequentPatterns):
         _info = {self._rank[k]: v for k, v in _generatedItems.items()}
         _Tree = self._buildTree(_updatedDatabases, _info)
         self._finalPatterns = {}
-        _Tree.generatePatterns([], self._patterns)
+        self._maximalTree = _MPTree()
+        _Tree.generatePatterns([], self._patterns, self._maximalTree)
         for x, y in self._patterns.items():
             pattern = str()
             x = self._savePeriodic(x)
@@ -711,7 +714,7 @@ class MaxPFGrowth(_ab._periodicFrequentPatterns):
             dataFrame = _ab._pd.DataFrame(data, columns=['Patterns', 'Support', 'Periodicity'])
         return dataFrame
 
-    def savePatterns(self, outFile):
+    def save(self, outFile):
         """Complete set of periodic-frequent patterns will be loaded in to a output file
 
         :param outFile: name of the output file
@@ -720,7 +723,7 @@ class MaxPFGrowth(_ab._periodicFrequentPatterns):
         self._oFile = outFile
         writer = open(self._oFile, 'w+')
         for x, y in self._finalPatterns.items():
-            s1 = x + ":" + str(y[0]) + ":" + str(y[1])
+            s1 = x.replace(' ', '\t').strip() + ":" + str(y[0]) + ":" + str(y[1])
             writer.write("%s \n" % s1)
 
     def getPatterns(self):
@@ -731,34 +734,33 @@ class MaxPFGrowth(_ab._periodicFrequentPatterns):
         """
         return self._finalPatterns
 
+    def printResults(self):
+        print("Total number of Maximal Periodic Frequent Patterns:", len(self.getPatterns()))
+        print("Total Memory in USS:", self.getMemoryUSS())
+        print("Total Memory in RSS", self.getMemoryRSS())
+        print("Total ExecutionTime in ms:", self.getRuntime())
+
 
 if __name__ == "__main__":
-    ap = str()
+    _ap = str()
     if len(_ab._sys.argv) == 5 or len(_ab._sys.argv) == 6:
         if len(_ab._sys.argv) == 6:
-            ap = MaxPFGrowth(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4], _ab._sys.argv[5])
+            _ap = MaxPFGrowth(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4], _ab._sys.argv[5])
         if len(_ab._sys.argv) == 5:
-            ap = MaxPFGrowth(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4])
-        ap.startMine()
-        Patterns = ap.getPatterns()
-        print("Total number of  Patterns:", len(Patterns))
-        ap.savePatterns(_ab._sys.argv[2])
-        memUSS = ap.getMemoryUSS()
-        print("Total Memory in USS:", memUSS)
-        memRSS = ap.getMemoryRSS()
-        print("Total Memory in RSS", memRSS)
-        run = ap.getRuntime()
-        print("Total ExecutionTime in ms:", run)
+            _ap = MaxPFGrowth(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4])
+        _ap.startMine()
+        print("Total number of Maximal Periodic-Frequent Patterns:", len(_ap.getPatterns()))
+        _ap.save(_ab._sys.argv[2])
+        print("Total Memory in USS:", _ap.getMemoryUSS())
+        print("Total Memory in RSS", _ap.getMemoryRSS())
+        print("Total ExecutionTime in ms:", _ap.getRuntime())
     else:
-        '''ap = MaxPFGrowth('/Users/Likhitha/Downloads/Datasets/BMS1_itemset_mining.txt', 90, 10000, ' ')
-        ap.startMine()
-        Patterns = ap.getPatterns()
-        print("Total number of  Patterns:", len(Patterns))
-        ap.savePatterns('/Users/Likhitha/Downloads/output')
-        memUSS = ap.getMemoryUSS()
-        print("Total Memory in USS:", memUSS)
-        memRSS = ap.getMemoryRSS()
-        print("Total Memory in RSS", memRSS)
-        run = ap.getRuntime()
-        print("Total ExecutionTime in ms:", run)'''
-        print("Error! The number of input parameters do not match the total number of parameters provided")        
+        for i in [100, 200, 300, 400, 500]:
+            _ap =  MaxPFGrowth('/Users/Likhitha/Downloads/temporal_T10I4D100K.csv', i, 5000, '\t')
+            _ap.startMine()
+            print("Total number of Maximal Partial Periodic Patterns:", len(_ap.getPatterns()))
+            _ap.save('/Users/Likhitha/Downloads/output.txt')
+            print("Total Memory in USS:", _ap.getMemoryUSS())
+            print("Total Memory in RSS", _ap.getMemoryRSS())
+            print("Total ExecutionTime in ms:", _ap.getRuntime())
+        print("Error! The number of input parameters do not match the total number of parameters provided")
