@@ -214,31 +214,33 @@ class RSFPGrowth(_ab._frequentPatterns):
             Name of the Input file to mine complete set of frequent patterns
         oFile : file
             Name of the output file to store complete set of frequent patterns
-        __memoryUSS : float
+        memoryUSS : float
             To store the total amount of USS memory consumed by the program
-        __memoryRSS : float
+        memoryRSS : float
             To store the total amount of RSS memory consumed by the program
-        __startTime:float
+        startTime:float
             To record the start time of the mining process
-        __endTime:float
+        endTime:float
             To record the completion time of the mining process
         minSup : float
             The user given minSup
+        minRS : float
+            The user given minRS
         Database : list
             To store the transactions of a database in list
-        __mapSupport : Dictionary
+        mapSupport : Dictionary
             To maintain the information of item and their frequency
-        __lno : int
+        lno : int
             it represents the total no of transactions
         tree : class
             it represents the Tree class
-        __itemSetCount : int
+        itemSetCount : int
             it represents the total no of patterns
-        __finalPatterns : dict
+        finalPatterns : dict
             it represents to store the patterns
-        __itemSetBuffer : list
+        itemSetBuffer : list
             it represents the store the items in mining
-        __maxPatternLength : int
+        maxPatternLength : int
            it represents the constraint for pattern length
 
     Methods:
@@ -247,7 +249,7 @@ class RSFPGrowth(_ab._frequentPatterns):
             Mining process will start from here
         getFrequentPatterns()
             Complete set of patterns will be retrieved with this function
-        savePatterns(oFile)
+        save(oFile)
             Complete set of frequent patterns will be loaded in to a output file
         getPatternsAsDataFrame()
             Complete set of frequent patterns will be loaded in to a dataframe
@@ -275,7 +277,7 @@ class RSFPGrowth(_ab._frequentPatterns):
     -------
         Format:
         -------
-            python3 RSFPGrowth.py <inputFile> <outputFile> <minSup> <__minRatio>
+            python3 RSFPGrowth.py <inputFile> <outputFile> <minSup> <minRS>
 
         Examples:
         ---------
@@ -288,7 +290,7 @@ class RSFPGrowth(_ab._frequentPatterns):
     -----------
         from PAMI.frequentPatternUsingOtherMeasures import RSFPGrowth as alg
 
-        obj = alg.RSFPGrowth(iFile, minSup, __minRatio)
+        obj = alg.RSFPGrowth(iFile, minSup, minRS)
 
         obj.startMine()
 
@@ -296,7 +298,7 @@ class RSFPGrowth(_ab._frequentPatterns):
 
         print("Total number of Frequent Patterns:", len(frequentPatterns))
 
-        obj.savePatterns(oFile)
+        obj.save(oFile)
 
         Df = obj.getPatternsAsDataFrame()
 
@@ -321,7 +323,7 @@ class RSFPGrowth(_ab._frequentPatterns):
     __startTime = float()
     __endTime = float()
     _minSup = str()
-    _minRatio = float()
+    _minRS = float()
     __finalPatterns = {}
     _iFile = " "
     _oFile = " "
@@ -337,8 +339,8 @@ class RSFPGrowth(_ab._frequentPatterns):
     __itemSetCount = 0
     __maxPatternLength = 1000
 
-    def __init__(self, iFile, __minSup, __minRatio, sep='\t'):
-        super().__init__(iFile, __minSup, __minRatio, sep)
+    def __init__(self, iFile, __minSup, __minRS, sep='\t'):
+        super().__init__(iFile, __minSup, __minRS, sep)
         self.__finalPatterns = {}
 
     def __creatingItemSets(self):
@@ -427,7 +429,7 @@ class RSFPGrowth(_ab._frequentPatterns):
                     prefix.insert(newPrefixLength, tempBuffer[j].itemId)
                     newPrefixLength += 1
             ratio = s / self.__mapSupport[self.__getMinItem(prefix, newPrefixLength)]
-            if ratio >= self._minRatio:
+            if ratio >= self._minRS:
                 self.__saveItemSet(prefix, newPrefixLength, s, ratio)
 
     def __frequentPatternGrowthGenerate(self, frequentPatternTree, prefix, prefixLength, __mapSupport, minConf):
@@ -465,14 +467,14 @@ class RSFPGrowth(_ab._frequentPatterns):
             for i in reversed(frequentPatternTree.headerList):
                 item = i
                 support = __mapSupport[i]
-                CminSup = max(self._minSup, support * self._minRatio)
+                CminSup = max(self._minSup, support * self._minRS)
                 betaSupport = support
                 prefix.insert(prefixLength, item)
                 max1 = self.__getMinItem(prefix, prefixLength)
                 if self.__mapSupport[max1] > self.__mapSupport[item]:
                     max1 = item
                 ratio = support / self.__mapSupport[max1]
-                if ratio >= self._minRatio:
+                if ratio >= self._minRS:
                     self.__saveItemSet(prefix, prefixLength + 1, betaSupport, ratio)
                 if prefixLength + 1 < self.__maxPatternLength:
                     prefixPaths = []
@@ -536,11 +538,10 @@ class RSFPGrowth(_ab._frequentPatterns):
             raise Exception("Please enter the Minimum Support")
         self.__creatingItemSets()
         self._minSup = self.__convert(self._minSup)
-        self._minRatio = float(self._minRatio)
+        self._minRS = float(self._minRS)
         self.__frequentOneItem()
         self.__finalPatterns = {}
         self.__mapSupport = {k: v for k, v in self.__mapSupport.items() if v >= self._minSup}
-        print(len(self.__mapSupport), len(self.__finalPatterns), len(self.__Database))
         __itemSetBuffer = [k for k, v in sorted(self.__mapSupport.items(), key=lambda x: x[1], reverse=True)]
         for i in self.__Database:
             transaction = []
@@ -552,7 +553,7 @@ class RSFPGrowth(_ab._frequentPatterns):
         self.__tree.createHeaderList(self.__mapSupport, self._minSup)
         if len(self.__tree.headerList) > 0:
             self.__itemSetBuffer = []
-            self.__frequentPatternGrowthGenerate(self.__tree, self.__itemSetBuffer, 0, self.__mapSupport, self._minRatio)
+            self.__frequentPatternGrowthGenerate(self.__tree, self.__itemSetBuffer, 0, self.__mapSupport, self._minRS)
         print("Relative support frequent patterns were generated successfully using RSFPGrowth algorithm")
         self.__endTime = _ab._time.time()
         process = _ab._psutil.Process(_ab._os.getpid())
@@ -609,11 +610,14 @@ class RSFPGrowth(_ab._frequentPatterns):
         dataframe = {}
         data = []
         for a, b in self.__finalPatterns.items():
-            data.append([a, b])
+            pattern = str()
+            for i in a:
+                pattern = pattern + i + " "
+            data.append([pattern, b])
             dataframe = _ab._pd.DataFrame(data, columns=['Patterns', 'Support'])
         return dataframe
 
-    def savePatterns(self, outFile):
+    def save(self, outFile):
         """Complete set of frequent patterns will be loaded in to a output file
 
         :param outFile: name of the output file
@@ -624,8 +628,8 @@ class RSFPGrowth(_ab._frequentPatterns):
         for x, y in self.__finalPatterns.items():
             pattern = str()
             for i in x:
-                pattern = pattern + i + " "
-            s1 = str(pattern) + ": " + str(y)
+                pattern = pattern + i + "\t"
+            s1 = pattern.strip() + ": " + str(y)
             writer.write("%s \n" % s1)
 
     def getPatterns(self):
@@ -638,44 +642,30 @@ class RSFPGrowth(_ab._frequentPatterns):
         for x, y in self.__finalPatterns.items():
             pattern = str()
             for i in x:
-                pattern = pattern + i + " "
+                pattern = pattern + i + "\t"
             s1 = str(y)
             res[pattern] = s1
-
         return res
 
+    def printResults(self):
+        print("Total number of Relative Frequent Patterns:", len(self.getPatterns()))
+        print("Total Memory in USS:", self.getMemoryUSS())
+        print("Total Memory in RSS", self.getMemoryRSS())
+        print("Total ExecutionTime in ms:",  self.getRuntime())
+
 
 if __name__ == "__main__":
-    ap = str()
+    _ap = str()
     if len(_ab._sys.argv) == 5 or len(_ab._sys.argv) == 6:
         if len(_ab._sys.argv) == 6:
-            ap = RSFPGrowth(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4], _ab._sys.argv[5])
+            _ap = RSFPGrowth(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4], _ab._sys.argv[5])
         if len(_ab._sys.argv) == 5:
-            ap = RSFPGrowth(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4])
-        ap.startMine()
-        Patterns = ap.getPatterns()
-        print("Total number of Frequent Patterns:", len(Patterns))
-        ap.savePatterns(_ab._sys.argv[2])
-        memUSS = ap.getMemoryUSS()
-        print("Total Memory in USS:", memUSS)
-        memRSS = ap.getMemoryRSS()
-        print("Total Memory in RSS", memRSS)
-        run = ap.getRuntime()
-        print("Total ExecutionTime in ms:", run)
+            _ap = RSFPGrowth(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4])
+        _ap.startMine()
+        print("Total number of Frequent Patterns:", len(_ap.getPatterns()))
+        _ap.save(_ab._sys.argv[2])
+        print("Total Memory in USS:", _ap.getMemoryUSS())
+        print("Total Memory in RSS", _ap.getMemoryRSS())
+        print("Total ExecutionTime in ms:", _ap.getRuntime())
     else:
-        l = [0.006, 0.007, 0.008, 0.009, 0.01]
-        for i in l:
-            ap = RSFPGrowth(
-                'https://www.u-aizu.ac.jp/~udayrage/datasets/transactionalDatabases/transactional_T10I4D100K.csv',
-                0.008, 0.4)
-            ap.startMine()
-            correlatedPatterns = ap.getPatterns()
-            print("Total number of correlated-Frequent Patterns:", len(correlatedPatterns))
-            ap.savePatterns('/Users/Likhitha/Downloads/output')
-            memUSS = ap.getMemoryUSS()
-            print("Total Memory in USS:", memUSS)
-            memRSS = ap.getMemoryRSS()
-            print("Total Memory in RSS", memRSS)
-            run = ap.getRuntime()
-            print("Total ExecutionTime in seconds:", run)
         print("Error! The number of input parameters do not match the total number of parameters provided")
