@@ -17,15 +17,13 @@ from PAMI.uncertainFrequentPattern.basic import abstract as _fp
 
 _minSup = float()
 _fp._sys.setrecursionlimit(20000)
-__finalPatterns = {}
+_finalPatterns = {}
 
 
 class _Item:
     """
     A class used to represent the item with probability in transaction of dataset
-
     ...
-
         Attributes:
         __________
             item : int or word
@@ -42,9 +40,7 @@ class _Item:
 class _Node(object):
     """
         A class used to represent the node of frequentPatternTree
-
         ...
-
         Attributes:
         ----------
             item : int
@@ -55,7 +51,6 @@ class _Node(object):
                 To maintain the parent of every node
             children : list
                 To maintain the children of node
-
         Methods:
         -------
             addChild(itemName)
@@ -84,9 +79,7 @@ def printTree(root):
 class _Tree(object):
     """
     A class used to represent the frequentPatternGrowth tree structure
-
     ...
-
     Attributes:
     ----------
         root : Node
@@ -95,8 +88,6 @@ class _Tree(object):
             storing the nodes with same item name
         info : dictionary
             stores the support of items
-
-
     Methods:
     -------
         addTransaction(transaction)
@@ -112,7 +103,6 @@ class _Tree(object):
                 removes the node from tree once after generating all the patterns respective to the node
         generatePatterns(Node)
             starts from the root node of the tree and mines the frequent patterns
-
     """
 
     def __init__(self):
@@ -122,7 +112,6 @@ class _Tree(object):
 
     def addTransaction(self, transaction):
         """adding transaction into tree
-
                 :param transaction : it represents the one transactions in database
                 :type transaction : list
                         """
@@ -166,17 +155,11 @@ class _Tree(object):
 
     def addConditionalTransaction(self, transaction, sup, second):
         """constructing conditional tree from prefixPaths
-
             :param transaction: it represents the one transactions in database
-
             :type transaction: list
-
             :param sup: support of prefixPath taken at last child of the path
-
             :type sup: int
-
             :param second: the second probability of the node
-
             :type second: float
         """
         currentNode = self.root
@@ -202,9 +185,7 @@ class _Tree(object):
 
     def conditionalPatterns(self, alpha):
         """generates all the conditional patterns of respective node
-
             :param alpha : it represents the Node in tree
-
             :type alpha : _Node
         """
         finalPatterns = []
@@ -227,13 +208,9 @@ class _Tree(object):
 
     def conditionalTransactions(self, condPatterns, support):
         """ It generates the conditional patterns with frequent items
-
             :param condPatterns: condPatterns generated from condition pattern method for respective node
-
             :type condPatterns: list
-
             :param support: the support of conditional pattern in tree
-
             :type support: list
         """
         global _minSup
@@ -260,9 +237,7 @@ class _Tree(object):
 
     def removeNode(self, nodeValue):
         """removing the node from tree
-
             :param nodeValue : it represents the node in tree
-
             :type nodeValue : node
         """
         for i in self.summaries[nodeValue]:
@@ -270,12 +245,10 @@ class _Tree(object):
 
     def generatePatterns(self, prefix):
         """generates the patterns
-
             :param prefix : forms the combination of items
-
             :type prefix : list
         """
-        global __finalPatterns, _minSup
+        global _finalPatterns, _minSup
         for i in sorted(self.summaries, key=lambda x: (self.info.get(x))):
             pattern = prefix[:]
             pattern.append(i)
@@ -286,7 +259,7 @@ class _Tree(object):
                 elif x.k >= 3:
                     n = x.probability * pow(x.prefixProbability, (x.k - 2))
                     s += n
-            __finalPatterns[tuple(pattern)] = self.info[i]
+            _finalPatterns[tuple(pattern)] = self.info[i]
             if s >= _minSup:
                 patterns, support, info, second = self.conditionalPatterns(i)
                 conditionalTree = _Tree()
@@ -301,12 +274,10 @@ class _Tree(object):
 class TubeP(_fp._frequentPatterns):
     """
     TubeP is one of the fastest algorithm to discover frequent patterns in a uncertain transactional database.
-
     Reference:
     --------
-        Carson Kai-Sang LeungSyed,  Khairuzzaman Tanbeer, "Fast Tree-Based Mining of Frequent Itemsets from Uncertain Data",
-         International Conference on Database Systems for Advanced Applications(DASFAA 2012), https://link.springer.com/chapter/10.1007/978-3-642-29038-1_21
-
+        Carson Kai-Sang Leung and Richard Kyle MacKinnon. 2014. Fast Algorithms for Frequent Itemset Mining from Uncertain Data.
+        In Proceedings of the 2014 IEEE International Conference on Data Mining (ICDM '14). IEEE Computer Society, USA, 893–898. https://doi.org/10.1109/ICDM.2014.146
     Attributes:
     ----------
         iFile : file
@@ -347,7 +318,7 @@ class TubeP(_fp._frequentPatterns):
             Mining process will start from here
         getPatterns()
             Complete set of patterns will be retrieved with this function
-        savePatterns(oFile)
+        save(oFile)
             Complete set of frequent patterns will be loaded in to a output file
         getPatternsAsDataFrame()
             Complete set of frequent patterns will be loaded in to a dataframe
@@ -367,20 +338,20 @@ class TubeP(_fp._frequentPatterns):
             After updating the Database, remaining items will be added into the tree by setting root node as null
         convert()
             to convert the user specified value
-
     Executing the code on terminal:
     -------
         Format:
         ------
+
         python3 TubeP.py <inputFile> <outputFile> <minSup>
+
         Examples:
         --------
-        python3 TubeP.py sampleTDB.txt patterns.txt 3    (minSup  will be considered in support count or frequency)
 
+        python3 TubeP.py sampleTDB.txt patterns.txt 3    (minSup  will be considered in support count or frequency)
 
     Sample run of importing the code:
     -------------------
-
         from PAMI.uncertainFrequentPattern.basic import tubeP as alg
 
         obj = alg.TubeP(iFile, minSup)
@@ -391,7 +362,7 @@ class TubeP(_fp._frequentPatterns):
 
         print("Total number of  Patterns:", len(Patterns))
 
-        obj.savePatterns(oFile)
+        obj.save(oFile)
 
         Df = obj.getPatternsAsDataFrame()
 
@@ -410,36 +381,34 @@ class TubeP(_fp._frequentPatterns):
     Credits:
     -------
         The complete program was written by P.Likhitha  under the supervision of Professor Rage Uday Kiran.\n
-
     """
-    __startTime = float()
-    __endTime = float()
+    _startTime = float()
+    _endTime = float()
     _minSup = str()
-    __finalPatterns = {}
+    _finalPatterns = {}
     _iFile = " "
-    oFile = " "
-    sep = " "
-    __memoryUSS = float()
-    __memoryRSS = float()
-    __Database = []
-    __rank = {}
+    _oFile = " "
+    _sep = " "
+    _memoryUSS = float()
+    _memoryRSS = float()
+    _Database = []
+    _rank = {}
 
     def __init__(self, iFile, minSup, sep='\t'):
         super().__init__(iFile, minSup, sep)
 
-    def __creatingItemSets(self):
+    def _creatingItemSets(self):
         """
-
         Scans the dataset and stores the transactions into Database variable
         """
-        self.__Database = []
+        self._Database = []
         if isinstance(self._iFile, _fp._pd.DataFrame):
             uncertain, data = [], []
             if self._iFile.empty:
                 print("its empty..")
             i = self._iFile.columns.values.tolist()
             if 'Transactions' in i:
-                self.__Database = self._iFile['Transactions'].tolist()
+                self._Database = self._iFile['Transactions'].tolist()
             if 'uncertain' in i:
                 uncertain = self._iFile['uncertain'].tolist()
             for k in range(len(data)):
@@ -447,7 +416,7 @@ class TubeP(_fp._frequentPatterns):
                 for j in range(len(data[k])):
                     product = _Item(data[k][j], uncertain[k][j])
                     tr.append(product)
-                self.__Database.append(tr)
+                self._Database.append(tr)
 
             # print(self.Database)
         if isinstance(self._iFile, str):
@@ -456,7 +425,7 @@ class TubeP(_fp._frequentPatterns):
                 for line in data:
                     line.strip()
                     line = line.decode("utf-8")
-                    temp = [i.rstrip() for i in line.split(self.sep)]
+                    temp = [i.rstrip() for i in line.split(self._sep)]
                     temp = [x for x in temp if x]
                     tr = []
                     for i in temp:
@@ -466,12 +435,12 @@ class TubeP(_fp._frequentPatterns):
                         probability = float(i[i1 + 1:i2])
                         product = _Item(item, probability)
                         tr.append(product)
-                    self.__Database.append(temp)
+                    self._Database.append(temp)
             else:
                 try:
                     with open(self._iFile, 'r') as f:
                         for line in f:
-                            temp = [i.rstrip() for i in line.split(self.sep)]
+                            temp = [i.rstrip() for i in line.split(self._sep)]
                             temp = [x for x in temp if x]
                             tr = []
                             for i in temp:
@@ -481,18 +450,17 @@ class TubeP(_fp._frequentPatterns):
                                 probability = float(i[i1 + 1:i2])
                                 product = _Item(item, probability)
                                 tr.append(product)
-                            self.__Database.append(tr)
+                            self._Database.append(tr)
                 except IOError:
                     print("File Not Found")
 
-    def __frequentOneItem(self):
+    def _frequentOneItem(self):
         """takes the transactions and calculates the support of each item in the dataset and assign the
                     ranks to the items by decreasing support and returns the frequent items list
-
         """
         global _minSup
         mapSupport = {}
-        for i in self.__Database:
+        for i in self._Database:
             for j in i:
                 if j.item not in mapSupport:
                     mapSupport[j.item] = round(j.probability, 2)
@@ -500,19 +468,15 @@ class TubeP(_fp._frequentPatterns):
                     mapSupport[j.item] += round(j.probability, 2)
         mapSupport = {k: round(v, 2) for k, v in mapSupport.items() if v >= self._minSup}
         plist = [k for k, v in sorted(mapSupport.items(), key=lambda x: x[1], reverse=True)]
-        self.__rank = dict([(index, item) for (item, index) in enumerate(plist)])
+        self._rank = dict([(index, item) for (item, index) in enumerate(plist)])
         return mapSupport, plist
 
-    def __buildTree(self, data, info):
+    def _buildTree(self, data, info):
         """it takes the transactions and support of each item and construct the main tree with setting root
                     node as null
-
             :param data : it represents the one transactions in database
-
             :type data : list
-
             :param info : it represents the support of each item
-
             :type info : dictionary
         """
         rootNode = _Tree()
@@ -521,35 +485,29 @@ class TubeP(_fp._frequentPatterns):
             rootNode.addTransaction(data[i])
         return rootNode
 
-    def __updateTransactions(self, dict1):
+    def _updateTransactions(self, dict1):
         """remove the items which are not frequent from transactions and updates the transactions with rank of items
-
             :param dict1 : frequent items with support
-
             :type dict1 : dictionary
         """
         list1 = []
-        for tr in self.__Database:
+        for tr in self._Database:
             list2 = []
             for i in range(0, len(tr)):
                 if tr[i].item in dict1:
                     list2.append(tr[i])
             if len(list2) >= 2:
                 basket = list2
-                basket.sort(key=lambda val: self.__rank[val.item])
+                basket.sort(key=lambda val: self._rank[val.item])
                 list2 = basket
                 list1.append(list2)
         return list1
 
-    def __Check(self, i, x):
+    def _Check(self, i, x):
         """To check the presence of item or pattern in transaction
-
             :param x: it represents the pattern
-
             :type x : list
-
             :param i : represents the uncertain transactions
-
             :type i : list
         """
         for m in x:
@@ -561,40 +519,37 @@ class TubeP(_fp._frequentPatterns):
                 return 0
         return 1
 
-    def __convert(self, value):
+    def _convert(self, value):
         """
             To convert the type of user specified minSup value
-
                 :param value: user specified minSup value
-
                 :return: converted type minSup value
         """
         if type(value) is int:
             value = int(value)
         if type(value) is float:
-            value = (len(self.__Database) * value)
+            value = (len(self._Database) * value)
         if type(value) is str:
             if '.' in value:
-                value = (len(self.__Database) * value)
+                value = (len(self._Database) * value)
             else:
                 value = int(value)
         return value
 
-    def __removeFalsePositives(self):
+    def _removeFalsePositives(self):
         """
                To remove the false positive patterns generated in frequent patterns
-
                :return: patterns with accurate probability
         """
-        global __finalPatterns
+        global _finalPatterns
         periods = {}
-        for i in self.__Database:
-            for x, y in __finalPatterns.items():
+        for i in self._Database:
+            for x, y in _finalPatterns.items():
                 if len(x) == 1:
                     periods[x] = y
                 else:
                     s = 1
-                    check = self.__Check(i, x)
+                    check = self._Check(i, x)
                     if check == 1:
                         for j in i:
                             if j.item in x:
@@ -607,133 +562,107 @@ class TubeP(_fp._frequentPatterns):
             if y >= self._minSup:
                 sample = str()
                 for i in x:
-                    sample = sample + i + " "
-                self.__finalPatterns[sample] = y
+                    sample = sample + i + "\t"
+                self._finalPatterns[sample] = y
 
     def startMine(self):
         """Main method where the patterns are mined by constructing tree and remove the remove the false patterns
                            by counting the original support of a patterns
-
-
         """
         global _minSup
-        self.__startTime = _fp._time.time()
-        self.__creatingItemSets()
-        self._minSup = self.__convert(self._minSup)
+        self._startTime = _fp._time.time()
+        self._creatingItemSets()
+        self._minSup = self._convert(self._minSup)
         _minSup = self._minSup
-        self.__finalPatterns = {}
-        mapSupport, plist = self.__frequentOneItem()
-        transactions1 = self.__updateTransactions(mapSupport)
+        self._finalPatterns = {}
+        mapSupport, plist = self._frequentOneItem()
+        transactions1 = self._updateTransactions(mapSupport)
         info = {k: v for k, v in mapSupport.items()}
-        Tree1 = self.__buildTree(transactions1, info)
+        Tree1 = self._buildTree(transactions1, info)
         Tree1.generatePatterns([])
-        self.__removeFalsePositives()
-        print("Frequent patterns were generated successfully using TubeP algorithm")
-        self.__endTime = _fp._time.time()
+        self._removeFalsePositives()
+        print("Uncertain Frequent patterns were generated successfully using TubeP algorithm")
+        self._endTime = _fp._time.time()
         process = _fp._psutil.Process(_fp._os.getpid())
-        self.__memoryRSS = float()
-        self.__memoryUSS = float()
-        self.__memoryUSS = process.memory_full_info().uss
-        self.__memoryRSS = process.memory_info().rss
+        self._memoryRSS = float()
+        self._memoryUSS = float()
+        self._memoryUSS = process.memory_full_info().uss
+        self._memoryRSS = process.memory_info().rss
 
     def getMemoryUSS(self):
         """Total amount of USS memory consumed by the mining process will be retrieved from this function
-
         :return: returning USS memory consumed by the mining process
-
         :rtype: float
         """
 
-        return self.__memoryUSS
+        return self._memoryUSS
 
     def getMemoryRSS(self):
         """Total amount of RSS memory consumed by the mining process will be retrieved from this function
-
         :return: returning RSS memory consumed by the mining process
-
         :rtype: float
         """
 
-        return self.__memoryRSS
+        return self._memoryRSS
 
     def getRuntime(self):
         """Calculating the total amount of runtime taken by the mining process
-
-
         :return: returning total amount of runtime taken by the mining process
-
         :rtype: float
         """
 
-        return self.__endTime - self.__startTime
+        return self._endTime - self._startTime
 
     def getPatternsAsDataFrame(self):
         """Storing final frequent patterns in a dataframe
-
         :return: returning frequent patterns in a dataframe
-
         :rtype: pd.DataFrame
         """
 
         dataframe = {}
         data = []
-        for a, b in self.__finalPatterns.items():
-            data.append([a, b])
+        for a, b in self._finalPatterns.items():
+            data.append([a.replace('\t', ' '), b])
             dataframe = _fp._pd.DataFrame(data, columns=['Patterns', 'Support'])
         return dataframe
 
-    def savePatterns(self, outFile):
+    def save(self, outFile):
         """Complete set of frequent patterns will be loaded in to a output file
-
         :param outFile: name of the output file
-
         :type outFile: file
         """
         self.oFile = outFile
         writer = open(self.oFile, 'w+')
-        for x, y in self.__finalPatterns.items():
-            s1 = x + ":" + str(y)
+        for x, y in self._finalPatterns.items():
+            s1 = x.strip() + ":" + str(y)
             writer.write("%s \n" % s1)
 
     def getPatterns(self):
         """ Function to send the set of frequent patterns after completion of the mining process
-
         :return: returning frequent patterns
-
         :rtype: dict
         """
-        return self.__finalPatterns
+        return self._finalPatterns
+
+    def printResults(self):
+        print("Total number of  Uncertain Frequent Patterns:", len(self.getPatterns()))
+        print("Total Memory in USS:", self.getMemoryUSS())
+        print("Total Memory in RSS", self.getMemoryRSS())
+        print("Total ExecutionTime in ms:",  self.getRuntime())
 
 
 if __name__ == "__main__":
     _ap = str()
     if len(_fp._sys.argv) == 4 or len(_fp._sys.argv) == 5:
         if len(_fp._sys.argv) == 5:
-            _ap = TubeP(_fp._sys.argv, _fp._sys.argv, _fp._sys.argv)
+            _ap = TubeP(_fp._sys.argv[1], _fp._sys.argv[3], _fp._sys.argv[4])
         if len(_fp._sys.argv) == 4:
-            _ap = TubeP(_fp._sys.argv, _fp._sys.argv)
+            _ap = TubeP(_fp._sys.argv[1], _fp._sys.argv[3])
         _ap.startMine()
-        Patterns = _ap.getPatterns()
-        print("Total number of  Patterns:", len(Patterns))
-        _ap.savePatterns(_fp._sys.argv[2])
-        memUSS = _ap.getMemoryUSS()
-        print("Total Memory in USS:", memUSS)
-        memRSS = _ap.getMemoryRSS()
-        print("Total Memory in RSS", memRSS)
-        run = _ap.getRuntime()
-        print("Total ExecutionTime in ms:", run)
+        print("Total number of  Uncertain Frequent Patterns:", len(_ap.getPatterns()))
+        _ap.save(_fp._sys.argv[2])
+        print("Total Memory in USS:", _ap.getMemoryUSS())
+        print("Total Memory in RSS", _ap.getMemoryRSS())
+        print("Total ExecutionTime in ms:", _ap.getRuntime())
     else:
-        l = [200, 220, 240, 260, 280, 300]
-        for i in l:
-            _ap = TubeP('/home/apiiit-rkv/Desktop/uncertain/congestion', i, ' ')
-            _ap.startMine()
-            Patterns = _ap.getPatterns()
-            print("Total number of Patterns:", len(Patterns))
-            _ap.savePatterns('/home/apiiit-rkv/Desktop/uncertain/output')
-            memUSS = _ap.getMemoryUSS()
-            print("Total Memory in USS:", memUSS)
-            memRSS = _ap.getMemoryRSS()
-            print("Total Memory in RSS", memRSS)
-            run = _ap.getRuntime()
-            print("Total ExecutionTime in ms:", run)
         print("Error! The number of input parameters do not match the total number of parameters provided")
\ No newline at end of file
