@@ -317,13 +317,14 @@ class _Tree(object):
             :type prefix : list
         """
 
-        global  _minSup
+        global _minSup
         for i in sorted(self.summaries, key=lambda x: (self.info.get(x)[0])):
             pattern = prefix[:]
             pattern.append(i)
             s = 0
             for x in self.summaries[i]:
                 s += x.probability
+            print(pattern, self.info[i], s)
             periodic[tuple(pattern)] = self.info[i]
             if s >= _minSup:
                 patterns, timeStamps, support, info = self.getConditionalPatterns(i)
@@ -339,10 +340,15 @@ class _Tree(object):
 class UPFPGrowth(_ab._periodicFrequentPatterns):
     """
 
-        UPFPGrowth is  to discover periodic-frequent patterns in a temporal database.
+        UPFPGrowth is  to discover periodic-frequent patterns in a uncertain temporal database.
 
         Reference:
         --------
+            Uday Kiran, R., Likhitha, P., Dao, MS., Zettsu, K., Zhang, J. (2021).
+            Discovering Periodic-Frequent Patterns in Uncertain Temporal Databases. In:
+            Mantoro, T., Lee, M., Ayu, M.A., Wong, K.W., Hidayanto, A.N. (eds) Neural Information Processing.
+            ICONIP 2021. Communications in Computer and Information Science, vol 1516. Springer, Cham.
+            https://doi.org/10.1007/978-3-030-92307-5_83
 
         Attributes:
         ----------
@@ -388,7 +394,7 @@ class UPFPGrowth(_ab._periodicFrequentPatterns):
                 Mining process will start from here
             getPatterns()
                 Complete set of patterns will be retrieved with this function
-            savePatterns(oFile)
+            save(oFile)
                 Complete set of periodic-frequent patterns will be loaded in to a output file
             getPatternsAsDataFrame()
                 Complete set of periodic-frequent patterns will be loaded in to a dataframe
@@ -433,7 +439,7 @@ class UPFPGrowth(_ab._periodicFrequentPatterns):
 
             print("Total number of Periodic Frequent Patterns:", len(periodicFrequentPatterns))
 
-            obj.savePatterns(oFile)
+            obj.save(oFile)
 
             Df = obj.getPatternsAsDataFrame()
 
@@ -503,7 +509,7 @@ class UPFPGrowth(_ab._periodicFrequentPatterns):
                     line = line.decode("utf-8")
                     temp = [i.rstrip() for i in line.split(self._sep)]
                     temp = [x for x in temp if x]
-                    tr = []
+                    tr = [int(temp[0])]
                     for i in temp[1:]:
                         i1 = i.index('(')
                         i2 = i.index(')')
@@ -512,7 +518,7 @@ class UPFPGrowth(_ab._periodicFrequentPatterns):
                         product = _Item(item, probability)
                         tr.append(product)
                     self._lno += 1
-                    self._Database.append(temp)
+                    self._Database.append(tr)
             else:
                 try:
                     count = 0
@@ -544,9 +550,9 @@ class UPFPGrowth(_ab._periodicFrequentPatterns):
             n = i[0]
             for j in i[1:]:
                 if j.item not in mapSupport:
-                    mapSupport[j.item] = [j.probability, abs(0 - n), n]
+                    mapSupport[j.item] = [round(j.probability, 3), abs(0 - n), n]
                 else:
-                    mapSupport[j.item][0] += j.probability
+                    mapSupport[j.item][0] += round(j.probability, 3)
                     mapSupport[j.item][1] = max(mapSupport[j.item][1], abs(n - mapSupport[j.item][2]))
                     mapSupport[j.item][2] = n
         for key in mapSupport:
@@ -651,10 +657,10 @@ class UPFPGrowth(_ab._periodicFrequentPatterns):
         if type(value) is int:
             value = int(value)
         if type(value) is float:
-            value = int(len(self._Database) * value)
+            value = float(value)
         if type(value) is str:
             if '.' in value:
-                value = int(len(self._Database) * value)
+                value = float(value)
             else:
                 value = int(value)
 
@@ -687,7 +693,7 @@ class UPFPGrowth(_ab._periodicFrequentPatterns):
             if y[0] >= _minSup:
                 sample = str()
                 for i in x:
-                    sample = sample + i + " "
+                    sample = sample + i + "\t"
                 self._finalPatterns[sample] = y
 
     def startMine(self):
@@ -759,11 +765,11 @@ class UPFPGrowth(_ab._periodicFrequentPatterns):
         dataframe = {}
         data = []
         for a, b in self._finalPatterns.items():
-            data.append([a, b[0], b[1]])
+            data.append([a.replace('\t', ' '), b[0], b[1]])
             dataframe = _ab._pd.DataFrame(data, columns=['Patterns', 'Support', 'Periodicity'])
         return dataframe
 
-    def savePatterns(self, outFile):
+    def save(self, outFile):
         """Complete set of frequent patterns will be loaded in to a output file
 
         :param outFile: name of the output file
@@ -773,7 +779,7 @@ class UPFPGrowth(_ab._periodicFrequentPatterns):
         self.oFile = outFile
         writer = open(self.oFile, 'w+')
         for x, y in self._finalPatterns.items():
-            s1 = x + ":" + str(y)
+            s1 = x.strip() + ":" + str(y[0]) + ":" + str(y[1])
             writer.write("%s \n" % s1)
 
     def getPatterns(self):
@@ -785,6 +791,12 @@ class UPFPGrowth(_ab._periodicFrequentPatterns):
         """
         return self._finalPatterns
 
+    def printResults(self):
+        print("Total number of  Uncertain Periodic-Frequent Patterns:", len(self.getPatterns()))
+        print("Total Memory in USS:", self.getMemoryUSS())
+        print("Total Memory in RSS", self.getMemoryRSS())
+        print("Total ExecutionTime in ms:",  self.getRuntime())
+
 
 if __name__ == "__main__":
     _ap = str()
@@ -794,24 +806,19 @@ if __name__ == "__main__":
         if len(_ab._sys.argv) == 5:
             _ap = UPFPGrowth(_ab._sys.argv[1], _ab._sys.argv[3], _ab._sys.argv[4])
         _ap.startMine()
-        _Patterns = _ap.getPatterns()
-        print("Total number of Patterns:", len(_Patterns))
-        _ap.savePatterns(_ab._sys.argv[2])
-        # print(ap.getPatternsAsDataFrame())
-        _memUSS = _ap.getMemoryUSS()
-        print("Total Memory in USS:", _memUSS)
-        _memRSS = _ap.getMemoryRSS()
-        print("Total Memory in RSS", _memRSS)
-        _run = _ap.getRuntime()
-        print("Total ExecutionTime in ms:", _run)
+        print("Total number of Uncertain Periodic-Frequent Patterns:", len(_ap.getPatterns()))
+        _ap.save(_ab._sys.argv[2])
+        print("Total Memory in USS:", _ap.getMemoryUSS())
+        print("Total Memory in RSS", _ap.getMemoryRSS())
+        print("Total ExecutionTime in ms:", _ap.getRuntime())
     else:
-        l = [150]
+        l = [0.2, 0.5, 0.9, 1.3, 1.5]
         for i in l:
-            ap = UPFPGrowth('/home/apiiit-rkv/Desktop/uncertain/congestion_temporal.txt', i, 2000, ' ')
+            ap = UPFPGrowth('sample1', i, 4, ' ')
             ap.startMine()
             Patterns = ap.getPatterns()
             print("Total number of Patterns:", len(Patterns))
-            ap.savePatterns('/home/apiiit-rkv/Desktop/uncertain/output')
+            ap.save('/Users/Likhitha/Downloads/uncertain/output.txt')
             memUSS = ap.getMemoryUSS()
             print("Total Memory in USS:", memUSS)
             memRSS = ap.getMemoryRSS()
